@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -25,7 +25,7 @@ public:
     ~SelectSpecialCharDialog() override;
 
     void setCurrentChar(QChar c);
-    Q_REQUIRED_RESULT QChar currentChar() const;
+    [[nodiscard]] QChar currentChar() const;
 
     void setOkButtonText(const QString &text);
 
