@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2022-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2022-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -27,7 +27,7 @@ public:
     explicit AutoCorrectionLineEdit(QWidget *parent = nullptr);
     ~AutoCorrectionLineEdit() override;
 
-    Q_REQUIRED_RESULT TextAutoCorrectionCore::AutoCorrection *autocorrection() const;
+    [[nodiscard]] TextAutoCorrectionCore::AutoCorrection *autocorrection() const;
 
     void setAutocorrection(TextAutoCorrectionCore::AutoCorrection *autocorrect);
     void setAutocorrectionLanguage(const QString &language);
