@@ -5,6 +5,8 @@
 */
 
 #include "autocorrectiontextedittest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "autocorrection.h"
 #include "autocorrectionsettings.h"
 #include <QStandardPaths>
@@ -21,8 +23,8 @@ void AutoCorrectionTextEditTest::shouldNotAutocorrectWhenDisabled()
 {
     TextAutoCorrection::AutoCorrectionTextEdit richtext(nullptr);
     QHash<QString, QString> entries;
-    const QString originalWord = QStringLiteral("FOOFOO");
-    const QString replaceWord = QStringLiteral("BLABLA");
+    const QString originalWord = u"FOOFOO"_s;
+    const QString replaceWord = u"BLABLA"_s;
     entries.insert(originalWord, replaceWord);
     auto settings = new TextAutoCorrection::AutoCorrectionSettings;
     settings->setAutocorrectEntries(entries);
@@ -31,14 +33,14 @@ void AutoCorrectionTextEditTest::shouldNotAutocorrectWhenDisabled()
     QVERIFY(QTest::qWaitForWindowExposed(&richtext));
     QTest::keyClicks(&richtext, originalWord);
     QTest::keyClick(&richtext, ' ');
-    QCOMPARE(richtext.toPlainText(), QString(originalWord + QLatin1Char(' ')));
+    QCOMPARE(richtext.toPlainText(), QString(originalWord + u' '));
 }
 
 void AutoCorrectionTextEditTest::shouldReplaceWordWhenExactText()
 {
     TextAutoCorrection::AutoCorrectionTextEdit richtext(nullptr);
-    const QString originalWord = QStringLiteral("FOOFOO");
-    const QString replaceWord = QStringLiteral("BLABLA");
+    const QString originalWord = u"FOOFOO"_s;
+    const QString replaceWord = u"BLABLA"_s;
     QHash<QString, QString> entries;
     entries.insert(originalWord, replaceWord);
     auto settings = new TextAutoCorrection::AutoCorrectionSettings;
@@ -50,14 +52,14 @@ void AutoCorrectionTextEditTest::shouldReplaceWordWhenExactText()
     QVERIFY(QTest::qWaitForWindowExposed(&richtext));
     QTest::keyClicks(&richtext, originalWord);
     QTest::keyClick(&richtext, ' ');
-    QCOMPARE(richtext.toPlainText(), QString(replaceWord + QLatin1Char(' ')));
+    QCOMPARE(richtext.toPlainText(), QString(replaceWord + u' '));
 }
 
 void AutoCorrectionTextEditTest::shouldNotReplaceWordWhenInexactText()
 {
     TextAutoCorrection::AutoCorrectionTextEdit richtext(nullptr);
-    const QString originalWord = QStringLiteral("FOOFOO");
-    const QString replaceWord = QStringLiteral("BLABLA");
+    const QString originalWord = u"FOOFOO"_s;
+    const QString replaceWord = u"BLABLA"_s;
     QHash<QString, QString> entries;
     entries.insert(originalWord, replaceWord);
     auto settings = new TextAutoCorrection::AutoCorrectionSettings;
@@ -67,18 +69,18 @@ void AutoCorrectionTextEditTest::shouldNotReplaceWordWhenInexactText()
     richtext.autocorrection()->setAutoCorrectionSettings(settings);
 
     richtext.show();
-    const QString nonExactText = QStringLiteral("BLIBLI");
+    const QString nonExactText = u"BLIBLI"_s;
     QVERIFY(QTest::qWaitForWindowExposed(&richtext));
     QTest::keyClicks(&richtext, nonExactText);
     QTest::keyClick(&richtext, ' ');
-    QCOMPARE(richtext.toPlainText(), QString(nonExactText + QLatin1Char(' ')));
+    QCOMPARE(richtext.toPlainText(), QString(nonExactText + u' '));
 }
 
 void AutoCorrectionTextEditTest::shouldReplaceWhenPressEnter()
 {
     TextAutoCorrection::AutoCorrectionTextEdit richtext(nullptr);
-    const QString originalWord = QStringLiteral("FOOFOO");
-    const QString replaceWord = QStringLiteral("BLABLA");
+    const QString originalWord = u"FOOFOO"_s;
+    const QString replaceWord = u"BLABLA"_s;
     QHash<QString, QString> entries;
     entries.insert(originalWord, replaceWord);
 
@@ -92,14 +94,14 @@ void AutoCorrectionTextEditTest::shouldReplaceWhenPressEnter()
     QVERIFY(QTest::qWaitForWindowExposed(&richtext));
     QTest::keyClicks(&richtext, originalWord);
     QTest::keyPress(&richtext, Qt::Key_Enter);
-    QCOMPARE(richtext.toPlainText(), QString(replaceWord + QLatin1Char('\n')));
+    QCOMPARE(richtext.toPlainText(), QString(replaceWord + u'\n'));
 }
 
 void AutoCorrectionTextEditTest::shouldReplaceWhenPressReturn()
 {
     TextAutoCorrection::AutoCorrectionTextEdit richtext(nullptr);
-    const QString originalWord = QStringLiteral("FOOFOO");
-    const QString replaceWord = QStringLiteral("BLABLA");
+    const QString originalWord = u"FOOFOO"_s;
+    const QString replaceWord = u"BLABLA"_s;
     QHash<QString, QString> entries;
     entries.insert(originalWord, replaceWord);
     auto settings = new TextAutoCorrection::AutoCorrectionSettings;
@@ -111,7 +113,7 @@ void AutoCorrectionTextEditTest::shouldReplaceWhenPressReturn()
     QVERIFY(QTest::qWaitForWindowExposed(&richtext));
     QTest::keyClicks(&richtext, originalWord);
     QTest::keyPress(&richtext, Qt::Key_Return);
-    QCOMPARE(richtext.toPlainText(), QString(replaceWord + QLatin1Char('\n')));
+    QCOMPARE(richtext.toPlainText(), QString(replaceWord + u'\n'));
 }
 
 QTEST_MAIN(AutoCorrectionTextEditTest)
