@@ -17,4 +17,7 @@ public:
 private Q_SLOTS:
     void shouldHaveDefaultValues();
     void shouldCheckFromString();
+    void shouldParseMessage();
+    void shouldParseMessage_data();
+    void shouldSerializeMessage();
 };
