@@ -4,12 +4,13 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "textautogeneratechatsmodel.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "core/models/textautogeneratemessagesmodel.h"
+#include "core/textautogeneratechatsettings.h"
 #include "textautogeneratetextcore_debug.h"
 #include <KLocalizedString>
 using namespace TextAutoGenerateText;
+using namespace Qt::Literals::StringLiterals;
 TextAutoGenerateChatsModel::TextAutoGenerateChatsModel(QObject *parent)
     : QAbstractListModel{parent}
 {
@@ -66,6 +67,8 @@ QVariant TextAutoGenerateChatsModel::data(const QModelIndex &index, int role) co
         return QVariant::fromValue(chatElement.section());
     case DateTime:
         return dateTime(chatElement);
+    case HasPendingMessageTyped:
+        return mTextAutoGenerateChatSettings ? mTextAutoGenerateChatSettings->hasPendingMessageTyped(chatElement.identifier()) : false;
     default:
         break;
     }
@@ -83,6 +86,16 @@ qint64 TextAutoGenerateChatsModel::dateTime(const TextAutoGenerateChat &chat) co
     return chat.dateTime();
 }
 
+TextAutoGenerateChatSettings *TextAutoGenerateChatsModel::textAutoGenerateChatSettings() const
+{
+    return mTextAutoGenerateChatSettings;
+}
+
+void TextAutoGenerateChatsModel::setTextAutoGenerateChatSettings(TextAutoGenerateChatSettings *newTextAutoGenerateChatSettings)
+{
+    mTextAutoGenerateChatSettings = newTextAutoGenerateChatSettings;
+}
+
 bool TextAutoGenerateChatsModel::setData(const QModelIndex &idx, const QVariant &value, int role)
 {
     if (!idx.isValid()) {
@@ -307,6 +320,18 @@ bool TextAutoGenerateChatsModel::isEmpty() const
     return false;
 }
 
+QByteArray TextAutoGenerateChatsModel::chatIdFromChatName(const QString &chatName) const
+{
+    auto chatUuid = [&](const TextAutoGenerateChat &chat) {
+        return chat.title() == chatName;
+    };
+    auto it = std::find_if(mChats.begin(), mChats.end(), chatUuid);
+    if (it != mChats.end()) {
+        return (*it).identifier();
+    }
+    return {};
+}
+
 bool TextAutoGenerateChatsModel::chatInProgress(const QByteArray &chatId) const
 {
     auto chatUuid = [&](const TextAutoGenerateChat &chat) {
@@ -322,8 +347,8 @@ bool TextAutoGenerateChatsModel::chatInProgress(const QByteArray &chatId) const
 QList<QByteArray> TextAutoGenerateChatsModel::chatsId() const
 {
     QList<QByteArray> lst;
-    for (const TextAutoGenerateChat &chat : mChats) {
-        lst.append(chat.identifier());
+    for (const TextAutoGenerateChat &c : mChats) {
+        lst.append(c.identifier());
     }
     return lst;
 }
