@@ -9,6 +9,7 @@
 #include <KLocalizedString>
 #include <QDateTime>
 #include <QJsonObject>
+#include <TextAutoGenerateText/TextAutoGenerateTextToolPluginManager>
 
 using namespace TextAutoGenerateText;
 TextAutoGenerateMessagesModel::TextAutoGenerateMessagesModel(QObject *parent)
@@ -33,8 +34,10 @@ QVariant TextAutoGenerateMessagesModel::data(const QModelIndex &index, int role)
     }
     const auto &messageElement = mMessages[index.row()];
     switch (role) {
+    case MessagePointer:
+        return QVariant::fromValue(&messageElement);
     case Qt::DisplayRole:
-    case MessageRole:
+    case MessageHtmlGeneratedRole:
         return messageElement.htmlGenerated();
     case OriginalMessageRole:
         return messageElement.content();
@@ -56,6 +59,10 @@ QVariant TextAutoGenerateMessagesModel::data(const QModelIndex &index, int role)
         return waitingAnswer(messageElement);
     case ModelInfoRole:
         return generateModelInfo(messageElement);
+    case ToolsRole:
+        return QVariant::fromValue(messageElement.tools());
+    case AnswerUuidRole:
+        return messageElement.answerUuid();
     default:
         break;
     }
@@ -67,7 +74,12 @@ QString TextAutoGenerateMessagesModel::generateModelInfo(const TextAutoGenerateM
     if (m.engineName().isEmpty() && m.modelName().isEmpty()) {
         return {};
     }
-    return i18n("Engine: %1\nModel: %2\nInstance Name: %3", m.engineName(), m.modelName(), m.instanceName());
+    QString toolTip = i18n("Engine: %1\nModel: %2\nInstance Name: %3", m.engineName(), m.modelName(), m.instanceName());
+    if (m.messageInfo() && !m.messageInfo()->tools().isEmpty()) {
+        const QString displayList = TextAutoGenerateText::TextAutoGenerateTextToolPluginManager::self()->convertIdentifierToDisplay(m.messageInfo()->tools());
+        toolTip += i18n("\nTools: %1", displayList);
+    }
+    return toolTip;
 }
 
 QByteArray TextAutoGenerateMessagesModel::chatId() const
@@ -166,7 +178,7 @@ QByteArray TextAutoGenerateMessagesModel::editMessage(const QByteArray &uuid, co
             const QModelIndex index = createIndex(rowNumber, 0);
             Q_EMIT dataChanged(index, index, roles);
         };
-        emitChanged(i, {MessageRole});
+        emitChanged(i, {MessageHtmlGeneratedRole});
 
         auto matchesAnswerUuid = [&](const TextAutoGenerateMessage &msg) {
             return msg.uuid() == answerUuid;
@@ -177,7 +189,7 @@ QByteArray TextAutoGenerateMessagesModel::editMessage(const QByteArray &uuid, co
             (*answerIt).setInProgress(true);
             (*answerIt).setContent({});
             (*answerIt).setDateTime(dt);
-            emitChanged(idx, {MessageRole | FinishedRole});
+            emitChanged(idx, {MessageHtmlGeneratedRole | FinishedRole});
         }
         return answerUuid;
     }
@@ -200,7 +212,7 @@ void TextAutoGenerateMessagesModel::changeInProgress(const QByteArray &uuid, boo
             const QModelIndex index = createIndex(rowNumber, 0);
             Q_EMIT dataChanged(index, index, roles);
         };
-        emitChanged(i, {MessageRole | FinishedRole});
+        emitChanged(i, {MessageHtmlGeneratedRole | FinishedRole});
     }
 }
 
@@ -236,7 +248,7 @@ void TextAutoGenerateMessagesModel::replaceContent(const QByteArray &uuid, const
             const QModelIndex index = createIndex(rowNumber, 0);
             Q_EMIT dataChanged(index, index, roles);
         };
-        emitChanged(i, {MessageRole});
+        emitChanged(i, {MessageHtmlGeneratedRole});
     }
 }
 
@@ -288,7 +300,7 @@ bool TextAutoGenerateMessagesModel::setData(const QModelIndex &idx, const QVaria
         msg.setInProgress(value.toBool());
         Q_EMIT dataChanged(idx, idx, {MessageRoles::FinishedRole});
         return true;
-    case MessageRoles::MessageRole:
+    case MessageRoles::MessageHtmlGeneratedRole:
     case MessageRoles::SenderRole:
     case MessageRoles::DateTimeRole:
     case MessageRoles::UuidRole:
@@ -315,16 +327,16 @@ QModelIndex TextAutoGenerateMessagesModel::indexForUuid(const QByteArray &uuid)
     return idx;
 }
 
-QJsonArray TextAutoGenerateMessagesModel::convertToOllamaChat() const
+QList<QJsonObject> TextAutoGenerateMessagesModel::convertToOllamaChat() const
 {
-    QJsonArray array;
+    QList<QJsonObject> lst;
     for (const auto &msg : mMessages) {
         const auto obj = msg.convertToOllamaChatJson();
         if (!obj.isEmpty()) {
-            array.append(obj);
+            lst.append(obj);
         }
     }
-    return array;
+    return lst;
 }
 
 #include "moc_textautogeneratemessagesmodel.cpp"
