@@ -78,6 +78,16 @@ QVariant TextAutoGenerateTextInstanceModel::data(const QModelIndex &index, int r
     return {};
 }
 
+QStringList TextAutoGenerateTextInstanceModel::instanceDisplayNames() const
+{
+    QStringList lstDisplayNames;
+    lstDisplayNames.reserve(mTextInstances.size());
+    for (const auto &inst : mTextInstances) {
+        lstDisplayNames.append(inst->displayName());
+    }
+    return lstDisplayNames;
+}
+
 QList<TextAutoGenerateTextInstance *> TextAutoGenerateTextInstanceModel::textInstances() const
 {
     return mTextInstances;
@@ -87,6 +97,7 @@ void TextAutoGenerateTextInstanceModel::setTextInstances(const QList<TextAutoGen
 {
     beginResetModel();
     qDeleteAll(mTextInstances);
+    mTextInstances.clear();
     mTextInstances = newTextInstances;
     endResetModel();
 }
@@ -142,13 +153,19 @@ TextAutoGenerateTextPlugin *TextAutoGenerateTextInstanceModel::currentPlugin() c
         return nullptr;
     }
     auto matchesUuid = [&](TextAutoGenerateTextInstance *instance) {
-        return instance->instanceUuid() == mCurrentinstance;
+        return (instance->instanceUuid() == mCurrentinstance) && instance->enabled();
     };
     const auto answerIt = std::find_if(mTextInstances.constBegin(), mTextInstances.constEnd(), matchesUuid);
     if (answerIt != mTextInstances.constEnd()) {
         return (*answerIt)->plugin();
     }
-    return mTextInstances.constFirst()->plugin();
+    // Fall back to first enable instance
+    for (const auto &inst : mTextInstances) {
+        if (inst->enabled()) {
+            return inst->plugin();
+        }
+    }
+    return nullptr;
 }
 
 void TextAutoGenerateTextInstanceModel::addInstance(TextAutoGenerateTextInstance *instance)
