@@ -6,13 +6,13 @@
 
 #pragma once
 
+#include "core/textautogeneratetextclient.h"
 #include "textautogeneratetext_export.h"
 #include <QObject>
 #include <memory>
 namespace TextAutoGenerateText
 {
 class TextAutoGenerateEngineLoaderPrivate;
-class TextAutoGenerateTextClient;
 /**
  * @brief The TextAutoGenerateEngineLoader class
  * @author Laurent Montel <montel@kde.org>
@@ -24,22 +24,13 @@ public:
     explicit TextAutoGenerateEngineLoader(QObject *parent = nullptr);
     ~TextAutoGenerateEngineLoader() override;
 
-    [[nodiscard]] TextAutoGenerateText::TextAutoGenerateTextClient *createTextAutoGenerateTextClient(const QString &clientName);
-
-    [[nodiscard]] bool hasConfigurationDialog(const QString &clientName) const;
-
-    [[nodiscard]] bool showConfigureDialog(const QString &clientName, QWidget *parentWidget);
-
-    [[nodiscard]] QMap<QString, QString> textAutoGenerateTextEngineInfos() const;
-
-    [[nodiscard]] QString fallbackFirstEngine() const;
+    [[nodiscard]] TextAutoGenerateText::TextAutoGenerateTextClient *searchTextAutoGenerateTextClient(const QString &clientName);
 
     [[nodiscard]] bool hasEngine() const;
 
     void loadPlugins();
 
-    [[nodiscard]] QString generateDisplayName(TextAutoGenerateTextClient *client) const;
-    [[nodiscard]] QString website(TextAutoGenerateTextClient *client) const;
+    [[nodiscard]] QList<TextAutoGenerateText::TextAutoGenerateTextClient::SupportedServer> supportedServers() const;
 
 Q_SIGNALS:
     void loadingPluginFailed();
