@@ -4,9 +4,13 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "textautogeneratemanager.h"
+#include "config-textautogeneratetext.h"
 #include "core/localdatabase/textautogeneratelocaldatabasemanager.h"
 #include "core/models/textautogeneratechatsmodel.h"
 #include "core/models/textautogeneratemessagesmodel.h"
+#include "core/textautogeneratesettings.h"
+#include "core/tools/textautogeneratetexttoolplugin.h"
+#include "core/tools/textautogeneratetexttoolpluginmanager.h"
 #include "textautogeneratechatsettings.h"
 #include "textautogenerateengineloader.h"
 #include "textautogeneratetextclient.h"
@@ -14,14 +18,50 @@
 #include "textautogeneratetextinstancesmanager.h"
 #include "textautogeneratetextplugin.h"
 
+#if HAVE_KTEXTADDONS_TEXTAUTOGENERATE_DBUS_SUPPORT
+#include "textautogeneratemanageradaptor.h"
+#include <QDBusConnection>
+#endif
+
+#include <KLocalizedString>
+using namespace Qt::Literals::StringLiterals;
 using namespace TextAutoGenerateText;
+
+#if HAVE_KTEXTADDONS_TEXTAUTOGENERATE_DBUS_SUPPORT
+static QString newDBusObjectName()
+{
+    static int s_count = 0;
+    QString name(u"/TEXTAUTOGENERATEMANGER_TextAutoGenerateManager"_s);
+    if (s_count++) {
+        name += u'_';
+        name += QString::number(s_count);
+    }
+    return name;
+}
+#endif
 TextAutoGenerateManager::TextAutoGenerateManager(QObject *parent)
     : QObject{parent}
     , mTextAutoGenerateChatsModel(new TextAutoGenerateChatsModel(this))
     , mDatabaseManager(new TextAutoGenerateLocalDatabaseManager)
     , mTextAutoGenerateChatSettings(new TextAutoGenerateChatSettings)
     , mTextAutoGenerateTextInstancesManager(new TextAutoGenerateTextInstancesManager(this, this))
+    , mTextAutoGenerateSettings(new TextAutoGenerateSettings())
 {
+    mTextAutoGenerateChatsModel->setTextAutoGenerateChatSettings(mTextAutoGenerateChatSettings.get());
+    // Load TextAutoGenerateTextToolPluginManager
+    (void)TextAutoGenerateTextToolPluginManager::self();
+
+#if HAVE_KTEXTADDONS_TEXTAUTOGENERATE_DBUS_SUPPORT
+    new TextAutoGenerateManagerAdaptor(this);
+
+    QDBusConnection dbus = QDBusConnection::sessionBus();
+    const QString dbusPath = newDBusObjectName();
+    setProperty("uniqueDBusPath", dbusPath);
+    const QString dbusInterface = u"org.kde.textautogeneratetext.TextAutoGenerateManager"_s;
+    dbus.registerObject(dbusPath, this);
+    dbus.connect(QString(), QString(), dbusInterface, u"chatListChanged"_s, this, SLOT(slotChatListChanged(QString)));
+#endif
+
     connect(mTextAutoGenerateChatsModel,
             &QAbstractItemModel::dataChanged,
             this,
@@ -36,6 +76,12 @@ TextAutoGenerateManager::TextAutoGenerateManager(QObject *parent)
                 }
             });
     connect(this, &TextAutoGenerateManager::configChanged, this, &TextAutoGenerateManager::loadEngine);
+    mTextAutoGenerateSettings->load();
+    const QList<TextAutoGenerateTextToolPlugin *> lstPlugins = TextAutoGenerateTextToolPluginManager::self()->pluginsList();
+    for (const auto p : lstPlugins) {
+        connect(p, &TextAutoGenerateTextToolPlugin::finished, this, &TextAutoGenerateManager::slotPluginFinished);
+        connect(p, &TextAutoGenerateTextToolPlugin::toolInProgress, this, &TextAutoGenerateManager::toolInProgress);
+    }
 }
 
 TextAutoGenerateManager::~TextAutoGenerateManager()
@@ -44,12 +90,76 @@ TextAutoGenerateManager::~TextAutoGenerateManager()
         textAutoGeneratePlugin()->cancelRequest({});
         textAutoGeneratePlugin()->deleteLater();
     }
+    delete mTextAutoGenerateSettings;
+}
+
+TextAutoGenerateManager::Category TextAutoGenerateManager::convertStringToCategory(const QString &str)
+{
+    if (str == "tools"_L1) {
+        return Category::Tools;
+    } else if (str == "small"_L1) {
+        return Category::Small;
+    } else if (str == "medium"_L1) {
+        return Category::Medium;
+    } else if (str == "big"_L1) {
+        return Category::Big;
+    } else if (str == "huge"_L1) {
+        return Category::Huge;
+    } else if (str == "multilingual"_L1) {
+        return Category::Multilingual;
+    } else if (str == "code"_L1) {
+        return Category::Code;
+    } else if (str == "math"_L1) {
+        return Category::Math;
+    } else if (str == "vision"_L1) {
+        return Category::Vision;
+    } else if (str == "embedding"_L1) {
+        return Category::Embedding;
+    } else if (str == "reasoning"_L1) {
+        return Category::Reasoning;
+    }
+    qCWarning(TEXTAUTOGENERATETEXT_CORE_LOG) << "Impossible to convert " << str;
+    return Category::Unknown;
+}
+
+QString TextAutoGenerateManager::convertCategoryToI18n(TextAutoGenerateManager::Category cat)
+{
+    switch (cat) {
+    case Category::Unknown:
+        return {};
+    case Category::Tools:
+        return i18n("Tools");
+    case Category::Small:
+        return i18n("Small");
+    case Category::Medium:
+        return i18n("Medium");
+    case Category::Big:
+        return i18n("Big");
+    case Category::Huge:
+        return i18n("Huge");
+    case Category::Multilingual:
+        return i18n("Multilingual");
+    case Category::Code:
+        return i18n("Code");
+    case Category::Math:
+        return i18n("Math");
+    case Category::Vision:
+        return i18n("Vision");
+    case Category::Embedding:
+        return i18n("Embedding");
+    case Category::Reasoning:
+        return i18n("Reasoning");
+    }
+    qCWarning(TEXTAUTOGENERATETEXT_CORE_LOG) << "Missing translating Category " << static_cast<int>(cat);
+    return {};
 }
 
 void TextAutoGenerateManager::askToAssistant(const QString &msg)
 {
     if (textAutoGeneratePlugin()) {
         textAutoGeneratePlugin()->askToAssistant(msg);
+    } else {
+        qCWarning(TEXTAUTOGENERATETEXT_CORE_LOG) << "Impossible to initialize plugin";
     }
 }
 
@@ -58,27 +168,44 @@ void TextAutoGenerateManager::ask(const QString &msg)
     Q_EMIT askMessageRequested(msg);
 }
 
-void TextAutoGenerateManager::createNewChat()
+void TextAutoGenerateManager::createNewChat(const QString &title)
 {
     // Switch back to not archived list
     setShowArchived(false);
     TextAutoGenerateChat chat;
     const QByteArray chatId = QUuid::createUuid().toByteArray(QUuid::Id128);
     chat.setIdentifier(chatId);
+    chat.setTitle(title);
     // we don't need to initialize it. (new chat => no data)
     chat.setInitialized(true);
     mTextAutoGenerateChatsModel->addChat(chat);
     if (mSaveInDatabase) {
         mDatabaseManager->insertOrUpdateChat(chat);
     }
-    setCurrentChatId(chatId);
+    switchToChatId(chatId);
 }
 
-void TextAutoGenerateManager::replaceContent(const QByteArray &chatId, const QByteArray &uuid, const QString &content)
+void TextAutoGenerateManager::switchToChatId(const QByteArray &chatId)
+{
+    if (!mPluginWasInitialized) {
+        mSwitchToChatId = chatId;
+    } else {
+        setCurrentChatId(chatId);
+    }
+}
+
+QStringList TextAutoGenerateManager::chatsList() const
+{
+    return mDatabaseManager->chatsList();
+}
+
+void TextAutoGenerateManager::replaceContent(const QByteArray &chatId,
+                                             const QByteArray &uuid,
+                                             const TextAutoGenerateText::TextAutoGenerateReply::Response &content)
 {
     auto messagesModel = messagesModelFromChatId(chatId);
     if (messagesModel) {
-        messagesModel->replaceContent(uuid, content);
+        messagesModel->replaceContent(uuid, content.response); // TODO use tools
     } else {
         qCWarning(TEXTAUTOGENERATETEXT_CORE_LOG) << "Impossible to find model for " << chatId;
     }
@@ -101,6 +228,25 @@ void TextAutoGenerateManager::changeChatInPogressStatus(const QByteArray &chatId
     }
 }
 
+bool TextAutoGenerateManager::pluginWasInitialized() const
+{
+    return mPluginWasInitialized;
+}
+
+void TextAutoGenerateManager::setPluginWasInitialized(bool newPluginWasInitialized)
+{
+    mPluginWasInitialized = newPluginWasInitialized;
+}
+
+void TextAutoGenerateManager::switchToChat(const QString &chatName)
+{
+    if (!mPluginWasInitialized) {
+        mSwitchToChatName = chatName;
+    } else {
+        setCurrentChatId(textAutoGenerateChatsModel()->chatIdFromChatName(chatName));
+    }
+}
+
 TextAutoGenerateChatSettings *TextAutoGenerateManager::textAutoGenerateChatSettings() const
 {
     return mTextAutoGenerateChatSettings.get();
@@ -121,12 +267,26 @@ void TextAutoGenerateManager::setSaveInDatabase(bool newSaveInDatabase)
     mSaveInDatabase = newSaveInDatabase;
 }
 
+void TextAutoGenerateManager::callTools(const QByteArray &chatId, const QByteArray &uuid, const QList<TextAutoGenerateReply::ToolCallArgumentInfo> &info)
+{
+    qDebug() << "TextAutoGenerateManager::callTools chatId : " << chatId << " uuid : " << uuid << " info: " << info;
+    for (const auto &i : info) {
+        auto plugin = TextAutoGenerateTextToolPluginManager::self()->pluginFromToolNameId(i.toolName);
+        if (plugin) {
+            plugin->callTools(chatId, uuid, info);
+        }
+    }
+}
+
 void TextAutoGenerateManager::changeInProgress(const QByteArray &chatId, const QByteArray &uuid, bool inProgress)
 {
     auto messagesModel = messagesModelFromChatId(chatId);
     if (messagesModel) {
         messagesModel->changeInProgress(uuid, inProgress);
         changeChatInPogressStatus(chatId, inProgress);
+        if (!inProgress) {
+            // TODO Q_EMIT answerGeneratedDone();
+        }
     } else {
         qCWarning(TEXTAUTOGENERATETEXT_CORE_LOG) << "Impossible to find model for " << chatId;
     }
@@ -162,14 +322,14 @@ void TextAutoGenerateManager::loadHistory()
     if (chats.isEmpty()) {
         createNewChat();
     } else {
-        mTextAutoGenerateChatsModel->setChats(std::move(chats));
+        mTextAutoGenerateChatsModel->setChats(chats);
     }
 }
 
 QString TextAutoGenerateManager::generateEngineDisplayName() const
 {
     QString displayName;
-    auto plugin = textAutoGeneratePlugin();
+    const auto *plugin = textAutoGeneratePlugin();
     if (plugin) {
         displayName = QStringLiteral("%1 (%2)").arg(plugin->translatedPluginName(), TextAutoGenerateTextPlugin::convertEngineType(plugin->engineType()));
     }
@@ -194,6 +354,16 @@ void TextAutoGenerateManager::removeMessage(const QByteArray &chatId, const QByt
     }
 }
 
+QString TextAutoGenerateManager::systemPrompt() const
+{
+    return mTextAutoGenerateSettings->systemPrompt();
+}
+
+void TextAutoGenerateManager::setSystemPrompt(const QString &newSystemPrompt)
+{
+    mTextAutoGenerateSettings->setSystemPrompt(newSystemPrompt);
+}
+
 bool TextAutoGenerateManager::cancelRequest(const QByteArray &chatId, const QModelIndex &index)
 {
     auto messagesModel = messagesModelFromChatId(chatId);
@@ -256,7 +426,7 @@ QByteArray TextAutoGenerateManager::currentChatId() const
 
 void TextAutoGenerateManager::checkCurrentChat()
 {
-    if (mCurrentChatId.isEmpty()) {
+    if (mCurrentChatId.isEmpty() && mSwitchToChatId.isEmpty() && mSwitchToChatName.isEmpty()) {
         createNewChat();
     }
 }
@@ -286,6 +456,11 @@ QList<TextAutoGenerateSearchMessage> TextAutoGenerateManager::searchTextInDataba
     return mDatabaseManager->searchTextInDatabase(mTextAutoGenerateChatsModel->chatsId(), searchText);
 }
 
+void TextAutoGenerateManager::resetCurrentChatId()
+{
+    mCurrentChatId.clear();
+}
+
 void TextAutoGenerateManager::setCurrentChatId(const QByteArray &newCurrentChatId)
 {
     if (mCurrentChatId != newCurrentChatId) {
@@ -319,7 +494,7 @@ void TextAutoGenerateManager::checkInitializedMessagesModel()
                             &QAbstractItemModel::dataChanged,
                             this,
                             [this, chatId, messagesModel](const QModelIndex &topLeft, const QModelIndex &, const QList<int> &roles) {
-                                if (roles.contains(TextAutoGenerateMessagesModel::MessageRole)) {
+                                if (roles.contains(TextAutoGenerateMessagesModel::MessageHtmlGeneratedRole)) {
                                     const QByteArray uuid = topLeft.data(TextAutoGenerateMessagesModel::UuidRole).toByteArray();
                                     const TextAutoGenerateMessage msg = messagesModel->message(uuid);
                                     mDatabaseManager->insertOrReplaceMessage(chatId, msg);
@@ -352,7 +527,7 @@ void TextAutoGenerateManager::loadEngine()
 {
     if (textAutoGeneratePlugin()) {
         disconnect(textAutoGeneratePlugin());
-        delete textAutoGeneratePlugin();
+        // delete textAutoGeneratePlugin();
     }
     mTextAutoGenerateTextInstancesManager->loadInstances();
     if (mTextAutoGenerateTextInstancesManager->isEmpty()) {
@@ -361,11 +536,84 @@ void TextAutoGenerateManager::loadEngine()
         return;
     }
 
-    connect(textAutoGeneratePlugin(), &TextAutoGenerateText::TextAutoGenerateTextPlugin::errorOccurred, this, &TextAutoGenerateManager::errorOccured);
     connect(textAutoGeneratePlugin(),
-            &TextAutoGenerateText::TextAutoGenerateTextPlugin::initializedDone,
+            &TextAutoGenerateText::TextAutoGenerateTextPlugin::currentModelChanged,
             this,
-            &TextAutoGenerateManager::pluginsInitializedDone);
+            &TextAutoGenerateManager::currentModelChanged);
+
+    connect(textAutoGeneratePlugin(),
+            &TextAutoGenerateText::TextAutoGenerateTextPlugin::downloadModelFinished,
+            this,
+            &TextAutoGenerateManager::downloadModelFinished);
+    connect(textAutoGeneratePlugin(), &TextAutoGenerateText::TextAutoGenerateTextPlugin::errorOccurred, this, &TextAutoGenerateManager::errorOccured);
+    connect(textAutoGeneratePlugin(), &TextAutoGenerateText::TextAutoGenerateTextPlugin::initializedDone, this, [this]() {
+        setPluginWasInitialized(true);
+        if (!mSwitchToChatId.isEmpty()) {
+            setCurrentChatId(mSwitchToChatId);
+            mSwitchToChatId.clear();
+        }
+        if (!mSwitchToChatName.isEmpty()) {
+            switchToChat(mSwitchToChatName);
+            mSwitchToChatName.clear();
+        }
+        Q_EMIT pluginsInitializedDone();
+    });
     Q_EMIT loadEngineDone();
 }
+
+void TextAutoGenerateManager::saveCurrentChatInDataBase(const QByteArray &chatId)
+{
+    if (mSaveInDatabase) {
+        qCWarning(TEXTAUTOGENERATETEXT_CORE_LOG) << "Chat is already saved in database: chatId: " << chatId;
+        return;
+    }
+    if (chatId.isEmpty()) {
+        qCWarning(TEXTAUTOGENERATETEXT_CORE_LOG) << "Current Chat Id is empty it's a bug";
+        return;
+    }
+
+    auto model = mTextAutoGenerateChatsModel->messagesModel(chatId);
+    if (model) {
+        const auto msgs = model->messages();
+        if (msgs.isEmpty()) {
+            return;
+        }
+
+        auto chat = mTextAutoGenerateChatsModel->chat(chatId);
+        // Insert chat in database
+        mDatabaseManager->insertOrUpdateChat(chat);
+        // Save each message in database
+        for (const auto &m : msgs) {
+            mDatabaseManager->insertOrReplaceMessage(chatId, m);
+        }
+#if HAVE_KTEXTADDONS_TEXTAUTOGENERATE_DBUS_SUPPORT
+        const QString ourIdentifier = u"%1/%2"_s.arg(QDBusConnection::sessionBus().baseService(), property("uniqueDBusPath").toString());
+        Q_EMIT chatListChanged(ourIdentifier);
+#endif
+    } else {
+        qCWarning(TEXTAUTOGENERATETEXT_CORE_LOG) << "No message model found for: " << chatId;
+        return;
+    }
+}
+
+void TextAutoGenerateManager::slotChatListChanged([[maybe_unused]] const QString &id)
+{
+#if HAVE_KTEXTADDONS_TEXTAUTOGENERATE_DBUS_SUPPORT
+    qCDebug(TEXTAUTOGENERATETEXT_CORE_LOG) << "TextAutoGenerateManager::slotChatListChanged :" << id;
+    const QString ourIdentifier = u"%1/%2"_s.arg(QDBusConnection::sessionBus().baseService(), property("uniqueDBusPath").toString());
+    if (id != ourIdentifier) {
+        loadHistory();
+    }
+#endif
+}
+
+void TextAutoGenerateManager::slotPluginFinished(const QString &str, const QByteArray &messageUuid, const QByteArray &chatId, const QByteArray &toolIdentifier)
+{
+    TextAutoGenerateText::TextAutoGenerateReply::Response content;
+    content.response = str;
+    // content.info =
+    replaceContent(chatId, messageUuid, content);
+    changeInProgress(chatId, messageUuid, false);
+}
+
 #include "moc_textautogeneratemanager.cpp"
