@@ -28,9 +28,13 @@ QDebug operator<<(QDebug d, const TextAutoGenerateText::TextAutoGenerateMessage
     d.space() << "answerUuid:" << t.answerUuid();
     d.space() << "mouseHover:" << t.mouseHover();
     d.space() << "editingMode:" << t.editingMode();
-    d.space() << "engineName:" << t.engineName();
-    d.space() << "modelName:" << t.modelName();
-    d.space() << "context:" << t.context();
+    if (t.messageInfo()) {
+        d.space() << "message Info:" << *t.messageInfo();
+    }
+    if (t.messageAttachment()) {
+        d.space() << "Message Attachment:" << *t.messageAttachment();
+    }
+
     return d;
 }
 
@@ -65,7 +69,7 @@ qint64 TextAutoGenerateMessage::dateTime() const
 void TextAutoGenerateMessage::setDateTime(qint64 newDateTime)
 {
     mDateTime = newDateTime;
-    QLocale locale;
+    const QLocale locale;
     mDateTimeStr = locale.toString(QDateTime::fromSecsSinceEpoch(mDateTime));
 }
 
@@ -86,9 +90,35 @@ void TextAutoGenerateMessage::setInProgress(bool newInProgress)
 
 bool TextAutoGenerateMessage::operator==(const TextAutoGenerateMessage &other) const
 {
-    return other.uuid() == mUuid && other.inProgress() == inProgress() && other.sender() == mSender && other.dateTime() == mDateTime
-        && other.content() == mContent && other.answerUuid() == mAnswerUuid && other.editingMode() == editingMode() && other.modelName() == modelName()
-        && other.engineName() == engineName() && other.context() == mContext;
+    bool result = other.uuid() == mUuid && other.inProgress() == inProgress() && other.sender() == mSender && other.dateTime() == mDateTime
+        && other.content() == mContent && other.answerUuid() == mAnswerUuid && other.editingMode() == editingMode();
+    if (!result) {
+        return false;
+    }
+    if (messageInfo() && other.messageInfo()) {
+        if (*messageInfo() == (*other.messageInfo())) {
+            result = true;
+        } else {
+            return false;
+        }
+    } else if (!messageInfo() && !other.messageInfo()) {
+        result = true;
+    } else {
+        return false;
+    }
+    if (messageAttachment() && other.messageAttachment()) {
+        if (*messageAttachment() == (*other.messageAttachment())) {
+            result = true;
+        } else {
+            return false;
+        }
+    } else if (!messageAttachment() && !other.messageAttachment()) {
+        result = true;
+    } else {
+        return false;
+    }
+
+    return result;
 }
 
 QByteArray TextAutoGenerateMessage::uuid() const
@@ -149,9 +179,20 @@ QString TextAutoGenerateMessage::modelName() const
     return {};
 }
 
-void TextAutoGenerateMessage::setInstanceName(const QString &instanceName)
+const TextAutoGenerateAnswerInfo *TextAutoGenerateMessage::messageInfo() const
 {
-    answerInfo()->setInstanceName(instanceName);
+    if (mMessageInfo) {
+        return mMessageInfo.data();
+    }
+    return nullptr;
+}
+
+QList<QByteArray> TextAutoGenerateMessage::tools() const
+{
+    if (mMessageInfo) {
+        return mMessageInfo->tools();
+    }
+    return {};
 }
 
 QString TextAutoGenerateMessage::instanceName() const
@@ -162,11 +203,6 @@ QString TextAutoGenerateMessage::instanceName() const
     return {};
 }
 
-void TextAutoGenerateMessage::setModelName(const QString &newModelName)
-{
-    answerInfo()->setModelName(newModelName);
-}
-
 QString TextAutoGenerateMessage::engineName() const
 {
     if (mMessageInfo) {
@@ -175,19 +211,13 @@ QString TextAutoGenerateMessage::engineName() const
     return {};
 }
 
-void TextAutoGenerateMessage::setEngineName(const QString &newEngineName)
+void TextAutoGenerateMessage::setMessageInfo(const TextAutoGenerateAnswerInfo &messageInfo)
 {
-    answerInfo()->setEngineName(newEngineName);
-}
-
-TextAutoGenerateTextContext TextAutoGenerateMessage::context() const
-{
-    return mContext;
-}
-
-void TextAutoGenerateMessage::setContext(const TextAutoGenerateText::TextAutoGenerateTextContext &newContext)
-{
-    mContext = newContext;
+    if (!mMessageInfo) {
+        mMessageInfo = new TextAutoGenerateAnswerInfo(messageInfo);
+    } else {
+        mMessageInfo.reset(new TextAutoGenerateAnswerInfo(messageInfo));
+    }
 }
 
 QString TextAutoGenerateMessage::senderToString() const
@@ -230,9 +260,12 @@ QByteArray TextAutoGenerateMessage::serialize(const TextAutoGenerateMessage &msg
     o["answerIdentifier"_L1] = QString::fromLatin1(msg.mAnswerUuid);
     o["text"_L1] = msg.mContent;
     if (msg.sender() != Sender::User) {
-        o["modelName"_L1] = msg.modelName();
-        o["engineName"_L1] = msg.engineName();
-        o["instanceName"_L1] = msg.instanceName();
+        if (auto info = msg.messageInfo(); info) {
+            TextAutoGenerateAnswerInfo::serialize(*info, o);
+        }
+    }
+    if (auto att = msg.messageAttachment(); att) {
+        TextAutoGenerateAttachment::serialize(*att, o);
     }
     o["sender"_L1] = msg.senderToString();
     o["dateTime"_L1] = msg.mDateTime;
@@ -250,22 +283,24 @@ TextAutoGenerateMessage TextAutoGenerateMessage::deserialize(const QJsonObject &
     msg.setUuid(o["identifier"_L1].toString().toLatin1());
     msg.setAnswerUuid(o["answerIdentifier"_L1].toString().toLatin1());
     msg.setContent(o["text"_L1].toString());
-    msg.setModelName(o["modelName"_L1].toString());
-    msg.setEngineName(o["engineName"_L1].toString());
-    msg.setInstanceName(o["instanceName"_L1].toString());
+
+    TextAutoGenerateAnswerInfo *messageInfoDeserialized = TextAutoGenerateAnswerInfo::deserialize(o);
+    if (messageInfoDeserialized->isValid()) {
+        msg.setMessageInfo(*messageInfoDeserialized);
+    }
+    delete messageInfoDeserialized;
+
+    TextAutoGenerateAttachment *attDeserialized = TextAutoGenerateAttachment::deserialize(o);
+    if (attDeserialized->isValid()) {
+        msg.setMessageAttachment(*attDeserialized);
+    }
+    delete attDeserialized;
+
     msg.setDateTime(o["dateTime"_L1].toInteger());
     msg.setSender(senderFromString(o["sender"_L1].toString()));
     return msg;
 }
 
-TextAutoGenerateAnswerInfo *TextAutoGenerateMessage::answerInfo()
-{
-    if (!mMessageInfo) {
-        mMessageInfo = new TextAutoGenerateAnswerInfo;
-    }
-    return mMessageInfo;
-}
-
 QJsonObject TextAutoGenerateMessage::convertToOllamaChatJson() const
 {
     QJsonObject obj;
@@ -302,6 +337,23 @@ bool TextAutoGenerateMessage::messageStateValue(MessageState type) const
     return mMessageStates & type;
 }
 
+const TextAutoGenerateAttachment *TextAutoGenerateMessage::messageAttachment() const
+{
+    if (mMessageAttachment) {
+        return mMessageAttachment.data();
+    }
+    return nullptr;
+}
+
+void TextAutoGenerateMessage::setMessageAttachment(const TextAutoGenerateAttachment &newMessageAttachment)
+{
+    if (!mMessageAttachment) {
+        mMessageAttachment = new TextAutoGenerateAttachment(newMessageAttachment);
+    } else {
+        mMessageAttachment.reset(new TextAutoGenerateAttachment(newMessageAttachment));
+    }
+}
+
 TextAutoGenerateMessage::MessageStates TextAutoGenerateMessage::messageStates() const
 {
     return mMessageStates;
