@@ -163,9 +163,9 @@ QString generateRichTextCMark(const QString &str, const QString &searchedText)
         int start = 0;
         int end = 0;
     };
-    QList<HrefPos> lstPos;
 
     if (!searchedText.isEmpty()) {
+        QList<HrefPos> lstPos;
         const auto userHighlightForegroundColor =
             TextAutoGenerateColorsAndMessageViewStyle::self().schemeView().foreground(KColorScheme::NeutralText).color().name();
         const auto userHighlightBackgroundColor =
@@ -321,13 +321,13 @@ static QString addHighlighter(const QString &str, const QString &language, const
         return highlighted;
     };
 
-    auto addCodeChunk = [&](QString chunk) {
+    auto addCodeChunk = [&](const QString &chunk) {
         auto definition = TextAutoGenerateTextSyntaxHighlightingManager::self()->def(language);
         if (!definition.isValid()) {
             definition = TextAutoGenerateTextSyntaxHighlightingManager::self()->defaultDef();
         }
         qCDebug(TEXTAUTOGENERATETEXT_CORE_CMARK_LOG) << " definition.name() " << definition.name();
-        highlighter.setDefinition(std::move(definition));
+        highlighter.setDefinition(definition);
         // Qt's support for borders is limited to tables, so we have to jump through some hoops...
         richTextStream << "<table><tr><td style='background-color:"_L1 << codeBackgroundColor.name() << "; padding: 5px; border: 1px solid "_L1
                        << codeBorderColor << "'>"_L1 << highlight(chunk) << "</td></tr></table>"_L1;
@@ -353,7 +353,7 @@ static QString addHighlighter(const QString &str, const QString &language, const
     auto addInlineQuoteChunk = [&](const QString &chunk) {
         iterateOverEndLineRegions(chunk, u">"_s, addInlineQuoteCodeChunk, addTextChunk, addInlineQuoteCodeNewLineChunk);
     };
-    auto addNonCodeChunk = [&](QString chunk) {
+    auto addNonCodeChunk = [&](const QString &chunk) {
         if (chunk.isEmpty()) {
             return;
         }
@@ -394,16 +394,16 @@ static QString convertMessageText(const QString &str, const QString &searchText)
         switch (cmark_node_get_type(node)) {
         case CMARK_NODE_CODE_BLOCK: {
             const char *literal = cmark_node_get_literal(node);
-            QString str = QString::fromUtf8(literal);
-            if (!str.isEmpty()) {
-                convertHtmlChar(str);
+            QString literalStr = QString::fromUtf8(literal);
+            if (!literalStr.isEmpty()) {
+                convertHtmlChar(literalStr);
                 QString language;
                 const auto l = cmark_node_get_fence_info(node);
                 if (l) {
                     language = QString::fromUtf8(l);
                 }
                 qCDebug(TEXTAUTOGENERATETEXT_CORE_CMARK_LOG) << " language " << language;
-                const QString stringHtml = u"```"_s + str + u"```"_s;
+                const QString stringHtml = u"```"_s + literalStr + u"```"_s;
                 const QString highligherStr = addHighlighter(stringHtml, language, searchText);
                 cmark_node *p = cmark_node_new(CMARK_NODE_PARAGRAPH);
 
@@ -420,9 +420,9 @@ static QString convertMessageText(const QString &str, const QString &searchText)
             // qDebug() << " literal" << literal;
             qCDebug(TEXTAUTOGENERATETEXT_CORE_CMARK_LOG) << "CMARK_NODE_TEXT: QString::fromUtf8(literal) " << QString::fromUtf8(literal);
 
-            const QString str = QString::fromUtf8(literal);
-            if (!str.isEmpty()) {
-                const QString convertedString = addHighlighter(str, {}, searchText);
+            const QString strLiteral = QString::fromUtf8(literal);
+            if (!strLiteral.isEmpty()) {
+                const QString convertedString = addHighlighter(strLiteral, {}, searchText);
                 qCDebug(TEXTAUTOGENERATETEXT_CORE_CMARK_LOG) << "CMARK_NODE_TEXT: convert text " << convertedString;
                 cmark_node *htmlInline = cmark_node_new(CMARK_NODE_HTML_INLINE);
                 cmark_node_set_literal(htmlInline, convertedString.toUtf8().constData());
@@ -434,10 +434,10 @@ static QString convertMessageText(const QString &str, const QString &searchText)
         case CMARK_NODE_CODE: {
             const char *literal = cmark_node_get_literal(node);
             qCDebug(TEXTAUTOGENERATETEXT_CORE_CMARK_LOG) << "CMARK_NODE_CODE:  QString::fromUtf8(literal) code" << QString::fromUtf8(literal);
-            QString str = QString::fromUtf8(literal);
-            if (!str.isEmpty()) {
-                convertHtmlChar(str);
-                const QString stringHtml = u"`"_s + str + u"`"_s;
+            QString strLiteral = QString::fromUtf8(literal);
+            if (!strLiteral.isEmpty()) {
+                convertHtmlChar(strLiteral);
+                const QString stringHtml = u"`"_s + strLiteral + u"`"_s;
                 const QString convertedString = addHighlighter(stringHtml, {}, searchText);
                 qCDebug(TEXTAUTOGENERATETEXT_CORE_CMARK_LOG) << "CMARK_NODE_CODE:  convert text " << convertedString;
                 cmark_node *htmlInline = cmark_node_new(CMARK_NODE_HTML_INLINE);
