@@ -4,23 +4,23 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "textautogeneratetextinstancesmanager.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "core/models/textautogeneratetextinstancemodel.h"
 #include "core/textautogenerateengineloader.h"
 #include "core/textautogeneratetextplugin.h"
 #include "textautogeneratetextcore_debug.h"
+#include "textautogeneratetextutils.h"
 #include <KConfig>
 #include <KConfigGroup>
-#include <QRegularExpression>
 
+using namespace Qt::Literals::StringLiterals;
 using namespace TextAutoGenerateText;
 TextAutoGenerateTextInstancesManager::TextAutoGenerateTextInstancesManager(TextAutoGenerateManager *manager, QObject *parent)
     : QObject{parent}
     , mTextAutoGenerateTextInstanceModel(new TextAutoGenerateTextInstanceModel(this))
     , mTextAutoGenerateEngineLoader(new TextAutoGenerateEngineLoader(this))
     , mManager(manager)
-    , mConfig(new KConfig(configFileName()))
+    , mConfig(new KConfig(TextAutoGenerateTextUtils::instanceConfigFileName()))
 {
 }
 
@@ -29,11 +29,6 @@ TextAutoGenerateTextInstancesManager::~TextAutoGenerateTextInstancesManager()
     delete mConfig;
 }
 
-QString TextAutoGenerateTextInstancesManager::configFileName() const
-{
-    return u"autogeneratetextinstances"_s;
-}
-
 bool TextAutoGenerateTextInstancesManager::isEmpty() const
 {
     return mTextAutoGenerateTextInstanceModel->isEmpty();
@@ -50,16 +45,13 @@ TextAutoGenerateTextPlugin *TextAutoGenerateTextInstancesManager::textAutoGenera
 void TextAutoGenerateTextInstancesManager::loadInstances()
 {
     mTextAutoGenerateEngineLoader->loadPlugins();
-    const QStringList instances = groupList(mConfig);
-    if (instances.isEmpty()) {
+    const QStringList instancesList = TextAutoGenerateTextUtils::instancesList(mConfig);
+    if (instancesList.isEmpty()) {
         return; // nothing to be done...
     }
 
-    const KConfigGroup configGeneralGroup(mConfig, u"General"_s);
-
     QList<TextAutoGenerateTextInstance *> lstInstances;
-    const auto instanceList = groupList(mConfig);
-    for (const auto &group : instanceList) {
+    for (const auto &group : instancesList) {
         const KConfigGroup configGroup(mConfig, group);
         auto inst = new TextAutoGenerateTextInstance;
         inst->load(configGroup);
@@ -79,21 +71,16 @@ void TextAutoGenerateTextInstancesManager::loadInstances()
     // qDebug() << " lstInstances " << lstInstances;
     setInstances(lstInstances);
     // Set current Instance after loading all instances. Otherwise we can'"t have default instance
+    const KConfigGroup configGeneralGroup(mConfig, u"General"_s);
     setCurrentinstance(configGeneralGroup.readEntry("currentInstance", QByteArray()));
 }
 
-QStringList TextAutoGenerateTextInstancesManager::groupList(KConfig *config) const
-{
-    static const QRegularExpression regExpr(u"^Instance #\\d+$"_s);
-    return config->groupList().filter(regExpr);
-}
-
 void TextAutoGenerateTextInstancesManager::saveInstances()
 {
     KConfigGroup configGeneralGroup(mConfig, u"General"_s);
     configGeneralGroup.writeEntry("currentInstance", currentInstance());
 
-    const auto instanceList = groupList(mConfig);
+    const auto instanceList = TextAutoGenerateTextUtils::instancesList(mConfig);
     for (const auto &group : instanceList) {
         mConfig->deleteGroup(group);
     }
@@ -116,6 +103,11 @@ bool TextAutoGenerateTextInstancesManager::isCurrentInstance(const QByteArray &i
     return currentInstance() == instanceUuid;
 }
 
+QStringList TextAutoGenerateTextInstancesManager::instanceDisplayNames() const
+{
+    return mTextAutoGenerateTextInstanceModel->instanceDisplayNames();
+}
+
 QList<TextAutoGenerateTextInstance *> TextAutoGenerateTextInstancesManager::instances() const
 {
     return mTextAutoGenerateTextInstanceModel->textInstances();
