@@ -40,13 +40,13 @@ public:
 
     [[nodiscard]] TextAutoGenerateEngineLoader *textAutoGenerateEngineLoader() const;
 
-    [[nodiscard]] QString configFileName() const;
     [[nodiscard]] bool isEmpty() const;
 
     [[nodiscard]] TextAutoGenerateTextPlugin *textAutoGeneratePlugin() const;
 
+    [[nodiscard]] QStringList instanceDisplayNames() const;
+
 private:
-    [[nodiscard]] TEXTAUTOGENERATETEXT_NO_EXPORT QStringList groupList(KConfig *config) const;
     TextAutoGenerateTextInstanceModel *const mTextAutoGenerateTextInstanceModel;
     TextAutoGenerateEngineLoader *const mTextAutoGenerateEngineLoader;
     TextAutoGenerateText::TextAutoGenerateManager *const mManager;
