@@ -4,12 +4,14 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "textautogeneratetextutils.h"
-using namespace Qt::Literals::StringLiterals;
 
+#include <KConfig>
 #include <QCoreApplication>
+#include <QRegularExpression>
 #include <QStandardPaths>
-
-QString TextAutoGenerateText::TextAutoGenerateTextUtils::findExecutable(const QString &exec)
+using namespace TextAutoGenerateText;
+using namespace Qt::Literals::StringLiterals;
+QString TextAutoGenerateTextUtils::findExecutable(const QString &exec)
 {
 #ifdef Q_OS_WIN
     const QString executableName = exec + u".exe"_s;
@@ -22,3 +24,14 @@ QString TextAutoGenerateText::TextAutoGenerateTextUtils::findExecutable(const QS
 #endif
     return path;
 }
+
+QString TextAutoGenerateTextUtils::instanceConfigFileName()
+{
+    return u"autogeneratetextinstances"_s;
+}
+
+QStringList TextAutoGenerateTextUtils::instancesList(KConfig *config)
+{
+    static const QRegularExpression regExpr(u"^Instance #\\d+$"_s);
+    return config->groupList().filter(regExpr);
+}
