@@ -12,10 +12,10 @@
 #include "genericnetworksettings.h"
 #include "modelsmanager/genericnetworkmodelavailableinfos.h"
 #include <KLocalizedString>
-#include <QJsonArray>
 #include <QJsonDocument>
 #include <QNetworkReply>
 #include <QNetworkRequest>
+#include <TextAutoGenerateText/TextAutoGenerateTextToolPluginManager>
 using namespace Qt::Literals::StringLiterals;
 GenericNetworkManager::GenericNetworkManager(GenericNetworkSettings *settings, QObject *parent)
     : TextAutoGenerateText::TextAutoGenerateManagerBase{parent}
@@ -92,22 +92,21 @@ TextAutoGenerateText::TextAutoGenerateReply *GenericNetworkManager::getChatCompl
     req.setRawHeader("Accept", "application/json"_ba);
     req.setRawHeader("Authorization", "Bearer " + mApiKey.toLatin1());
     QJsonObject data;
-    data["model"_L1] = mGenericNetworkSettings->currentModel();
+    data["model"_L1] = request.model();
     data["messages"_L1] = request.messages();
     data["temperature"_L1] = mGenericNetworkSettings->temperature();
     data["stream"_L1] = true;
+    if (!request.tools().isEmpty()) {
+        data["tools"_L1] = TextAutoGenerateText::TextAutoGenerateTextToolPluginManager::self()->generateToolsArray(request.tools());
+        // data["tool_choice"_L1] = u"none"_s;
+    }
     if (mGenericNetworkSettings->maxTokens() > 0) {
         data["max_tokens"_L1] = mGenericNetworkSettings->maxTokens();
     }
     if (mGenericNetworkSettings->seed() > 0) {
         data["seed"_L1] = mGenericNetworkSettings->seed();
     }
-    /*
-    if (!OllamaSettings::systemPrompt().isEmpty()) {
-        data["system"_L1] = OllamaSettings::systemPrompt();
-    }
-    */
-    qCDebug(AUTOGENERATETEXT_GENERICNETWORK_LOG) << " JSon: " << data << " req " << req.url();
+    qCDebug(AUTOGENERATETEXT_GENERICNETWORK_LOG) << " Json: " << data << " req " << req.url();
     auto reply = new GenericNetworkReply{
         TextAutoGenerateText::TextAutoGenerateEngineAccessManager::self()->networkManager()->post(req, QJsonDocument(data).toJson(QJsonDocument::Compact)),
         GenericNetworkReply::RequestTypes::StreamingChat,
@@ -191,4 +190,14 @@ void GenericNetworkManager::setApiKey(const QString &newApiKey)
     mApiKey = newApiKey;
 }
 
+bool GenericNetworkManager::hasVisionSupport(const QString &currentModel) const
+{
+    return mServerInfo->hasToolsSupport(currentModel, mPluginNetworkType);
+}
+
+bool GenericNetworkManager::hasToolsSupport(const QString &currentModel) const
+{
+    return mServerInfo->hasToolsSupport(currentModel, mPluginNetworkType);
+}
+
 #include "moc_genericnetworkmanager.cpp"
