@@ -119,11 +119,6 @@ void GenericNetworkPlugin::save(KConfigGroup &config)
     writeJob->start();
 }
 
-void GenericNetworkPlugin::setPrompt(const QString &text)
-{
-    // TODO
-}
-
 QString GenericNetworkPlugin::engineName() const
 {
     return name();
@@ -131,9 +126,7 @@ QString GenericNetworkPlugin::engineName() const
 
 void GenericNetworkPlugin::sendToAssistant(const SendToAssistantInfo &info)
 {
-    TextAutoGenerateText::TextAutoGenerateTextRequest req;
-    req.setModel(currentModel());
-    req.setMessages(info.messagesArray);
+    const TextAutoGenerateText::TextAutoGenerateTextRequest req = convertSendToAssistantInfoToTextRequest(info);
     auto reply = mGenericManager->getChatCompletion(req);
     if (!reply) {
         return;
@@ -150,7 +143,13 @@ void GenericNetworkPlugin::sendToAssistant(const SendToAssistantInfo &info)
                         QPair<QByteArray, QMetaObject::Connection>(
                             messageUuid,
                             connect(reply, &TextAutoGenerateText::TextAutoGenerateReply::finished, this, [reply, messageUuid, chatId, this] {
-                                manager()->changeInProgress(chatId, messageUuid, false);
+                                const auto response = reply->readResponse();
+                                if (response.hasToolCallArguments()) {
+                                    manager()->callTools(chatId, messageUuid, response.info);
+                                } else {
+                                    manager()->changeInProgress(chatId, messageUuid, false);
+                                }
+
                                 qCDebug(AUTOGENERATETEXT_GENERICNETWORK_PLUGIN_LOG) << " progress finished";
                                 mConnections.remove(reply);
                                 reply->deleteLater();
@@ -251,6 +250,7 @@ void GenericNetworkPlugin::setCurrentModel(const QString &m)
 {
     mSettings->setCurrentModel(m);
     Q_EMIT configChanged();
+    Q_EMIT currentModelChanged();
 }
 
 TextAutoGenerateText::TextAutoGenerateTextPlugin::EngineType GenericNetworkPlugin::engineType() const
@@ -258,4 +258,14 @@ TextAutoGenerateText::TextAutoGenerateTextPlugin::EngineType GenericNetworkPlugi
     return TextAutoGenerateText::TextAutoGenerateTextPlugin::EngineType::Network;
 }
 
+bool GenericNetworkPlugin::hasVisionSupport() const
+{
+    return mGenericManager->hasVisionSupport(currentModel());
+}
+
+bool GenericNetworkPlugin::hasToolsSupport() const
+{
+    return mGenericManager->hasToolsSupport(currentModel());
+}
+
 #include "moc_genericnetworkplugin.cpp"
