@@ -4,6 +4,8 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "ollamamodelavailbleinfowidgettest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "modelsmanager/ollamamodelavailableinfowidget.h"
 #include <QTest>
 #include <QVBoxLayout>
@@ -16,7 +18,7 @@ OllamaModelAvailbleInfoWidgetTest::OllamaModelAvailbleInfoWidgetTest(QObject *pa
 void OllamaModelAvailbleInfoWidgetTest::shouldHaveDefaultValues()
 {
     OllamaModelAvailableInfoWidget w(nullptr);
-    auto mMainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainlayout"));
+    auto mMainLayout = w.findChild<QVBoxLayout *>(u"mainlayout"_s);
     QVERIFY(mMainLayout);
     QCOMPARE(mMainLayout->contentsMargins(), QMargins());
     // TODO
