@@ -4,10 +4,13 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "ollamamodeldownloadprogresswidgettest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "modelsmanager/ollamamodeldownloadprogresswidget.h"
 #include <QLabel>
 #include <QProgressBar>
 #include <QTest>
+#include <QToolButton>
 #include <QVBoxLayout>
 QTEST_MAIN(OllamaModelDownloadProgressWidgetTest)
 
@@ -20,17 +23,20 @@ void OllamaModelDownloadProgressWidgetTest::shouldHaveDefaultValues()
 {
     OllamaModelDownloadProgressWidget w(nullptr);
 
-    auto mainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainLayout"));
+    auto mainLayout = w.findChild<QVBoxLayout *>(u"mainLayout"_s);
     QVERIFY(mainLayout);
     QCOMPARE(mainLayout->contentsMargins(), QMargins{});
-    // TODO
 
-    auto mProgressBar = w.findChild<QProgressBar *>(QStringLiteral("mProgressBar"));
+    auto mProgressBar = w.findChild<QProgressBar *>(u"mProgressBar"_s);
     QVERIFY(mProgressBar);
-    auto mModelNameLabel = w.findChild<QLabel *>(QStringLiteral("mModelNameLabel"));
+    auto mModelNameLabel = w.findChild<QLabel *>(u"mModelNameLabel"_s);
     QVERIFY(mModelNameLabel);
-    auto mProgressStatusLabel = w.findChild<QLabel *>(QStringLiteral("mProgressStatusLabel"));
+    auto mProgressStatusLabel = w.findChild<QLabel *>(u"mProgressStatusLabel"_s);
     QVERIFY(mProgressStatusLabel);
+
+    auto mCancelDownloadButton = w.findChild<QToolButton *>(u"mCancelDownloadButton"_s);
+    QVERIFY(mCancelDownloadButton);
+    QVERIFY(!mCancelDownloadButton->toolTip().isEmpty());
 }
 
 #include "moc_ollamamodeldownloadprogresswidgettest.cpp"
