@@ -8,6 +8,7 @@
 #include "modelsmanager/ollamamodelinstalledinfowidget.h"
 #include "modelsmanager/ollamamodelinstalledlistview.h"
 #include "modelsmanager/ollamamodelinstalledwidget.h"
+#include "modelsmanager/ollamamodelsinfoscategoriescombobox.h"
 #include "widgets/common/textautogeneratemodelsearchlineedit.h"
 #include <QScrollArea>
 #include <QTest>
@@ -32,15 +33,20 @@ void OllamaModelInstalledWidgetTest::shouldHaveDefaultValues()
 
     auto mRemoveModelButton = w.findChild<QToolButton *>(u"mRemoveModelButton"_s);
     QVERIFY(mRemoveModelButton);
+    QVERIFY(!mRemoveModelButton->toolTip().isEmpty());
 
     auto mOllamaModelInstalledListView = w.findChild<OllamaModelInstalledListView *>(u"mOllamaModelInstalledListView"_s);
     QVERIFY(mOllamaModelInstalledListView);
 
     auto mSearchLineEdit = w.findChild<TextAutoGenerateText::TextAutoGenerateModelSearchLineEdit *>(u"mSearchLineEdit"_s);
     QVERIFY(mSearchLineEdit);
+
     auto mOllamaModelInstalledInfoWidget = w.findChild<OllamaModelInstalledInfoWidget *>(u"mOllamaModelInstalledInfoWidget"_s);
     QVERIFY(mOllamaModelInstalledInfoWidget);
 
+    auto mCategoriesComboBox = w.findChild<OllamaModelsInfosCategoriesComboBox *>(u"mCategoriesComboBox"_s);
+    QVERIFY(mCategoriesComboBox);
+
     auto scrollArea = w.findChild<QScrollArea *>(u"scrollArea"_s);
     QVERIFY(scrollArea);
     QCOMPARE(scrollArea->horizontalScrollBarPolicy(), Qt::ScrollBarAlwaysOff);
