@@ -30,11 +30,9 @@ OllamaModelAvailableDialog::OllamaModelAvailableDialog(OllamaManager *manager, Q
     mainLayout->setObjectName(u"mainlayout"_s);
     mOllamaModelWidget->setObjectName(u"mOllamaModelWidget"_s);
 
-    OllamaModelAvailableInfosManager managerModelInfosManager;
-    if (managerModelInfosManager.loadAvailableModels()) {
-        mOllamaModelWidget->setAvailableInfos(managerModelInfosManager.modelInfos());
+    if (manager) {
+        mOllamaModelWidget->setAvailableInfos(manager->availableInfos());
     }
-
     auto box = new QDialogButtonBox(QDialogButtonBox::Close, this);
     box->setObjectName(u"box"_s);
     mainLayout->addWidget(box);
@@ -52,7 +50,7 @@ void OllamaModelAvailableDialog::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(400, 300));
-    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(myOllamaModelDialogGroupName));
+    const KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(myOllamaModelDialogGroupName));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
