@@ -8,6 +8,7 @@
 #include <QWidget>
 class QVBoxLayout;
 class QLabel;
+class OllamaNetworkUrlButton;
 class OllamaManager;
 class TEXTAUTOGENERATEOLLAMA_TESTS_EXPORT OllamaModelAvailableInfoWidget : public QWidget
 {
@@ -25,4 +26,5 @@ private:
     QLabel *const mModelName;
     QWidget *mInfoWidget = nullptr;
     OllamaManager *const mOllamaManager;
+    OllamaNetworkUrlButton *const mNetworkUrlButton;
 };
