@@ -65,7 +65,7 @@ OllamaModelAvailableWidget::OllamaModelAvailableWidget(OllamaManager *manager, Q
     mListView->setModel(mProxyModel);
     connect(mSearchWidget, &OllamaModelAvailableSearchWidget::searchText, mProxyModel, &OllamaModelAvailableInfosSortProxyModel::setFilterFixedString);
     connect(mSearchWidget, &OllamaModelAvailableSearchWidget::categoriesChanged, mProxyModel, &OllamaModelAvailableInfosSortProxyModel::setCategories);
-    connect(mListView, &OllamaModelAvailableListView::clicked, this, &OllamaModelAvailableWidget::slotClicked);
+    connect(mListView, &OllamaModelAvailableListView::pressed, this, &OllamaModelAvailableWidget::slotClicked);
     connect(mSearchWidget, &OllamaModelAvailableSearchWidget::addModel, this, &OllamaModelAvailableWidget::slotAddModel);
 }
 
@@ -82,6 +82,7 @@ void OllamaModelAvailableWidget::slotAddModel()
     if (d.exec()) {
         const QString modelName = d.modelName().trimmed();
         if (!modelName.isEmpty()) {
+            qWarning() << "OllamaModelAvailableWidget::slotAddModel not implemented yet ";
             // TODO implement download
         }
     }
