@@ -10,6 +10,8 @@
 class QProgressBar;
 class QLabel;
 class OllamaManager;
+class QToolButton;
+class OllamaReply;
 class TEXTAUTOGENERATEOLLAMA_TESTS_EXPORT OllamaModelDownloadProgressWidget : public QWidget
 {
     Q_OBJECT
@@ -28,5 +30,7 @@ private:
     QLabel *const mModelNameLabel;
     QLabel *const mProgressStatusLabel;
     OllamaManager *const mManager;
+    QToolButton *const mCancelDownloadButton;
     QString mModelName;
+    QMap<QString, OllamaReply *> mDownloadReply;
 };
