@@ -35,7 +35,7 @@ QString OllamaModelInstalledInfo::convertModelNameToDisplay(const QString &model
     originalModelName = originalModelName.at(0).toUpper() + originalModelName.mid(1, originalModelName.size());
     const QStringList lst = originalModelName.split(u'-');
     if (lst.count() == 2) {
-        const QString secondPart = lst.at(1);
+        const QString &secondPart = lst.at(1);
         originalModelName = lst.at(0) + u' ' + secondPart.at(0).toUpper() + secondPart.mid(1, secondPart.size());
     }
     return originalModelName;
@@ -51,6 +51,36 @@ void OllamaModelInstalledInfo::setParentModel(const QString &newParentModel)
     mParentModel = newParentModel;
 }
 
+TextAutoGenerateText::TextAutoGenerateManager::Categories OllamaModelInstalledInfo::categories() const
+{
+    return mCategories;
+}
+
+void OllamaModelInstalledInfo::setCategories(const TextAutoGenerateText::TextAutoGenerateManager::Categories &newCategories)
+{
+    mCategories = newCategories;
+}
+
+QStringList OllamaModelInstalledInfo::languages() const
+{
+    return mLanguages;
+}
+
+void OllamaModelInstalledInfo::setLanguages(const QStringList &newLanguages)
+{
+    mLanguages = newLanguages;
+}
+
+QString OllamaModelInstalledInfo::modelUrl() const
+{
+    return mModelUrl;
+}
+
+void OllamaModelInstalledInfo::setModelUrl(const QString &newModelUrl)
+{
+    mModelUrl = newModelUrl;
+}
+
 QString OllamaModelInstalledInfo::parameterSize() const
 {
     return mParameterSize;
@@ -120,13 +150,17 @@ QDebug operator<<(QDebug d, const OllamaModelInstalledInfo &t)
     d.space() << "parameterSize:" << t.parameterSize();
     d.space() << "family:" << t.family();
     d.space() << "generateModelName:" << t.generateModelName();
+    d.space() << "categories:" << t.categories();
+    d.space() << "languages:" << t.languages();
+    d.space() << "modelUrl:" << t.modelUrl();
     return d;
 }
 
 bool OllamaModelInstalledInfo::operator==(const OllamaModelInstalledInfo &other) const
 {
     return mName == other.name() && mModel == other.model() && mQuantizationLevel == other.quantizationLevel() && mFamily == other.family()
-        && mParameterSize == other.parameterSize() && mModifyAt == other.modifyAt() && mParentModel == other.parentModel();
+        && mParameterSize == other.parameterSize() && mModifyAt == other.modifyAt() && mParentModel == other.parentModel() && mCategories == other.mCategories
+        && mLanguages == other.mLanguages && mModelUrl == other.mModelUrl;
 }
 
 QString OllamaModelInstalledInfo::modifyAtInLocal() const
