@@ -8,6 +8,7 @@
 #include <QDebug>
 #include <QJsonObject>
 #include <QString>
+#include <TextAutoGenerateText/TextAutoGenerateManager>
 
 class TEXTAUTOGENERATEOLLAMA_TESTS_EXPORT OllamaModelInstalledInfo
 {
@@ -39,11 +40,20 @@ public:
 
     [[nodiscard]] QString generateModelName() const;
 
-    static QString convertModelNameToDisplay(const QString &modelName);
+    [[nodiscard]] static QString convertModelNameToDisplay(const QString &modelName);
 
     [[nodiscard]] QString parentModel() const;
     void setParentModel(const QString &newParentModel);
 
+    [[nodiscard]] TextAutoGenerateText::TextAutoGenerateManager::Categories categories() const;
+    void setCategories(const TextAutoGenerateText::TextAutoGenerateManager::Categories &newCategories);
+
+    [[nodiscard]] QStringList languages() const;
+    void setLanguages(const QStringList &newLanguages);
+
+    [[nodiscard]] QString modelUrl() const;
+    void setModelUrl(const QString &newModelUrl);
+
 private:
     QString mName;
     QString mModel;
@@ -53,6 +63,9 @@ private:
     QString mModifyAt;
     QString mGeneratedModelName;
     QString mParentModel;
+    QString mModelUrl;
+    QStringList mLanguages;
+    TextAutoGenerateText::TextAutoGenerateManager::Categories mCategories = TextAutoGenerateText::TextAutoGenerateManager::Category::Unknown;
 };
 Q_DECLARE_TYPEINFO(OllamaModelInstalledInfo, Q_RELOCATABLE_TYPE);
 QDebug operator<<(QDebug d, const OllamaModelInstalledInfo &t);
