@@ -23,6 +23,8 @@ public:
         QuantizationLevel,
         ParameterSize,
         DescriptionInfo,
+        Categories,
+        Languages,
     };
     Q_ENUM(ModelInfoRoles)
 
