@@ -4,12 +4,12 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 #pragma once
-#include "ollamamodelavailableinfo.h"
 #include "ollamamodelinstalledinfo.h"
 #include "textautogenerateollama_private_export.h"
 #include <QWidget>
 class QLabel;
 class QVBoxLayout;
+class OllamaNetworkUrlButton;
 class TEXTAUTOGENERATEOLLAMA_TESTS_EXPORT OllamaModelInstalledInfoWidget : public QWidget
 {
     Q_OBJECT
@@ -17,16 +17,18 @@ public:
     explicit OllamaModelInstalledInfoWidget(QWidget *parent = nullptr);
     ~OllamaModelInstalledInfoWidget() override;
 
-    void setOllamaModelInstalledInfo(const OllamaModelInstalledInfo &info, const QList<OllamaModelAvailableInfo> &infos);
+    void setOllamaModelInstalledInfo(const OllamaModelInstalledInfo &info);
 
 private:
     TEXTAUTOGENERATEOLLAMA_NO_EXPORT void changeFont(QLabel *label);
-    TEXTAUTOGENERATEOLLAMA_NO_EXPORT void
-    appendCategories(QStringList &lst, OllamaModelAvailableInfo::Category cat, OllamaModelAvailableInfo::Categories categories);
+    TEXTAUTOGENERATEOLLAMA_NO_EXPORT void appendCategories(QStringList &lst,
+                                                           TextAutoGenerateText::TextAutoGenerateManager::Category cat,
+                                                           TextAutoGenerateText::TextAutoGenerateManager::Categories categories);
     QLabel *const mFamilyNameLabel;
     QLabel *const mParameterSizeLabel;
     QLabel *const mQuantizationLevelLabel;
     QLabel *const mModifiedAtLabel;
     QVBoxLayout *const mMainLayout;
     QWidget *mInfoWidget = nullptr;
+    OllamaNetworkUrlButton *const mNetworkUrlButton;
 };
