@@ -7,15 +7,15 @@
 
 #include "ollamamanager.h"
 #include "ollamamodelinstalledinfosmodel.h"
+#include "ollamamodelinstalledinfossortproxymodel.h"
 #include "ollamamodelinstalledinfowidget.h"
 #include "ollamamodelinstalledlistview.h"
+#include "ollamamodelsinfoscategoriescombobox.h"
 
 #include "widgets/common/textautogeneratemodelsearchlineedit.h"
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <QLineEdit>
 #include <QScrollArea>
-#include <QSortFilterProxyModel>
 #include <QSplitter>
 #include <QToolButton>
 #include <QVBoxLayout>
@@ -24,9 +24,11 @@ OllamaModelInstalledWidget::OllamaModelInstalledWidget(OllamaManager *manager, Q
     : QWidget{parent}
     , mOllamaModelInstalledListView(new OllamaModelInstalledListView(this))
     , mSearchLineEdit(new TextAutoGenerateText::TextAutoGenerateModelSearchLineEdit(this))
+    , mCategoriesComboBox(new OllamaModelsInfosCategoriesComboBox(this))
     , mRemoveModelButton(new QToolButton(this))
     , mOllamaModelInstalledInfoWidget(new OllamaModelInstalledInfoWidget(this))
     , mManager(manager)
+    , mProxyModel(new OllamaModelInstalledInfosSortProxyModel(this))
 {
     auto mainLayout = new QVBoxLayout(this);
     mainLayout->setObjectName(u"mainlayout"_s);
@@ -42,6 +44,12 @@ OllamaModelInstalledWidget::OllamaModelInstalledWidget(OllamaManager *manager, Q
     mSearchLineEdit->setObjectName(u"mSearchLineEdit"_s);
     hboxLayout->addWidget(mSearchLineEdit);
 
+    mCategoriesComboBox->setObjectName(u"mCategoriesComboBox"_s);
+    hboxLayout->addWidget(mCategoriesComboBox);
+    connect(mCategoriesComboBox, &OllamaModelsInfosCategoriesComboBox::categoriesChanged, this, [this]() {
+        mProxyModel->setCategories(mCategoriesComboBox->categories());
+    });
+
     auto splitter = new QSplitter(this);
     splitter->setObjectName(u"splitter"_s);
     mainLayout->addWidget(splitter);
@@ -65,23 +73,21 @@ OllamaModelInstalledWidget::OllamaModelInstalledWidget(OllamaManager *manager, Q
             model->setModelInstalledInfos(mManager->installedInfos());
         });
     }
-    auto proxyModel = new QSortFilterProxyModel(this);
-    proxyModel->setFilterCaseSensitivity(Qt::CaseInsensitive);
-    proxyModel->setSortCaseSensitivity(Qt::CaseInsensitive);
-    proxyModel->setSourceModel(model);
-    proxyModel->sort(0);
-    connect(mSearchLineEdit, &TextAutoGenerateText::TextAutoGenerateModelSearchLineEdit::textChanged, this, [proxyModel](const QString &str) {
-        proxyModel->setFilterFixedString(str);
+    mProxyModel->setSourceModel(model);
+    mProxyModel->sort(0);
+    connect(mSearchLineEdit, &TextAutoGenerateText::TextAutoGenerateModelSearchLineEdit::textChanged, this, [this](const QString &str) {
+        mProxyModel->setFilterFixedString(str);
     });
-    mOllamaModelInstalledListView->setModel(proxyModel);
+    mOllamaModelInstalledListView->setModel(mProxyModel);
 
     mRemoveModelButton->setObjectName(u"mRemoveModelButton"_s);
     mRemoveModelButton->setEnabled(false);
+    mRemoveModelButton->setToolTip(i18nc("@info:tooltip", "Remove Selected Model"));
     scrollArea->hide();
     hboxLayout->addWidget(mRemoveModelButton);
     mRemoveModelButton->setIcon(QIcon::fromTheme(u"edit-delete"_s));
     connect(mRemoveModelButton, &QToolButton::clicked, this, &OllamaModelInstalledWidget::slotRemoveModel);
-    connect(mOllamaModelInstalledListView, &OllamaModelInstalledListView::clicked, this, &OllamaModelInstalledWidget::slotClicked);
+    connect(mOllamaModelInstalledListView, &OllamaModelInstalledListView::pressed, this, &OllamaModelInstalledWidget::slotClicked);
     connect(mOllamaModelInstalledListView->selectionModel(), &QItemSelectionModel::selectionChanged, this, [this, scrollArea]() {
         const bool isEnabled = mOllamaModelInstalledListView->currentIndex().isValid();
         mRemoveModelButton->setEnabled(isEnabled);
@@ -95,7 +101,7 @@ void OllamaModelInstalledWidget::slotClicked(const QModelIndex &index)
 {
     if (index.isValid()) {
         const OllamaModelInstalledInfo info = index.data(OllamaModelInstalledInfosModel::DescriptionInfo).value<OllamaModelInstalledInfo>();
-        mOllamaModelInstalledInfoWidget->setOllamaModelInstalledInfo(info, mModelAvailableInfos);
+        mOllamaModelInstalledInfoWidget->setOllamaModelInstalledInfo(info);
     }
 }
 
@@ -119,8 +125,4 @@ void OllamaModelInstalledWidget::slotRemoveModel()
     }
 }
 
-void OllamaModelInstalledWidget::setAvailableInfos(const QList<OllamaModelAvailableInfo> &infos)
-{
-    mModelAvailableInfos = infos;
-}
 #include "moc_ollamamodelinstalledwidget.cpp"
