@@ -4,13 +4,14 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 #pragma once
-#include "ollamamodelavailableinfo.h"
 #include "textautogenerateollama_private_export.h"
 #include <QWidget>
 class OllamaModelInstalledListView;
 class OllamaModelInstalledInfoWidget;
 class OllamaManager;
 class QToolButton;
+class OllamaModelsInfosCategoriesComboBox;
+class OllamaModelInstalledInfosSortProxyModel;
 namespace TextAutoGenerateText
 {
 class TextAutoGenerateModelSearchLineEdit;
@@ -22,15 +23,14 @@ public:
     explicit OllamaModelInstalledWidget(OllamaManager *manager, QWidget *parent = nullptr);
     ~OllamaModelInstalledWidget() override;
 
-    void setAvailableInfos(const QList<OllamaModelAvailableInfo> &infos);
-
 private:
     TEXTAUTOGENERATEOLLAMA_NO_EXPORT void slotRemoveModel();
     TEXTAUTOGENERATEOLLAMA_NO_EXPORT void slotClicked(const QModelIndex &);
-    QList<OllamaModelAvailableInfo> mModelAvailableInfos;
     OllamaModelInstalledListView *const mOllamaModelInstalledListView;
     TextAutoGenerateText::TextAutoGenerateModelSearchLineEdit *const mSearchLineEdit;
+    OllamaModelsInfosCategoriesComboBox *const mCategoriesComboBox;
     QToolButton *const mRemoveModelButton;
     OllamaModelInstalledInfoWidget *const mOllamaModelInstalledInfoWidget;
     OllamaManager *const mManager;
+    OllamaModelInstalledInfosSortProxyModel *const mProxyModel;
 };
