@@ -4,9 +4,9 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 #pragma once
-#include "ollamamodelavailableinfo.h"
 #include "textautogenerateollama_private_export.h"
 #include <QComboBox>
+#include <TextAutoGenerateText/TextAutoGenerateManager>
 class OllamaModelCategoriesModel;
 class TEXTAUTOGENERATEOLLAMA_TESTS_EXPORT OllamaModelsInfosCategoriesComboBox : public QComboBox
 {
@@ -15,7 +15,7 @@ public:
     explicit OllamaModelsInfosCategoriesComboBox(QWidget *parent = nullptr);
     ~OllamaModelsInfosCategoriesComboBox() override;
 
-    [[nodiscard]] QList<OllamaModelAvailableInfo::Category> categories() const;
+    [[nodiscard]] QList<TextAutoGenerateText::TextAutoGenerateManager::Category> categories() const;
 Q_SIGNALS:
     void categoriesChanged();
 
