@@ -7,7 +7,6 @@
 #pragma once
 
 #include <TextAutoGenerateText/TextAutoGenerateTextClient>
-class OllamaManager;
 class OllamaClient : public TextAutoGenerateText::TextAutoGenerateTextClient
 {
     Q_OBJECT
@@ -19,13 +18,7 @@ public:
 
     [[nodiscard]] QString name() const override;
     [[nodiscard]] QString translatedName() const override;
-    [[nodiscard]] TextAutoGenerateText::TextAutoGenerateTextPlugin *createTextAutoGeneratePlugin() override;
-    [[nodiscard]] TextAutoGenerateText::TextAutoGenerateTextClient::EngineType engineType() const override;
-    [[nodiscard]] bool hasConfigurationDialog() const override;
-    [[nodiscard]] bool showConfigureDialog(QWidget *parentWidget) override;
-    [[nodiscard]] QString webSite() const override;
-    [[nodiscard]] QString modelName() const override;
-
-private:
-    OllamaManager *const mManager;
+    [[nodiscard]] TextAutoGenerateText::TextAutoGenerateTextPlugin *
+    createTextAutoGeneratePlugin(TextAutoGenerateText::TextAutoGenerateManager *manager, TextAutoGenerateText::TextAutoGenerateTextInstance *instance) override;
+    [[nodiscard]] QList<TextAutoGenerateText::TextAutoGenerateTextClient::SupportedServer> supportedServers() const override;
 };
