@@ -4,9 +4,8 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "ollamaconfiguredialog.h"
-using namespace Qt::Literals::StringLiterals;
+#include "ollamamanager.h"
 
-#include "modelsmanager/ollamamodelavailableinfosmanager.h"
 #include "modelsmanager/ollamamodelavailablewidget.h"
 #include "modelsmanager/ollamamodelcreatewidget.h"
 #include "modelsmanager/ollamamodelinstalledwidget.h"
@@ -16,7 +15,7 @@ using namespace Qt::Literals::StringLiterals;
 #include <KSharedConfig>
 #include <KWindowConfig>
 #include <QDialogButtonBox>
-#include <QVBoxLayout>
+#include <QPushButton>
 #include <QWindow>
 
 namespace
@@ -24,6 +23,7 @@ namespace
 const char myOllamaConfigureDialogGroupName[] = "OllamaConfigureDialog";
 }
 
+using namespace Qt::Literals::StringLiterals;
 OllamaConfigureDialog::OllamaConfigureDialog(OllamaManager *manager, QWidget *parent)
     : KPageDialog(parent)
     , mOllamaConfigureWidget(new OllamaConfigureWidget(manager, this))
@@ -40,38 +40,36 @@ OllamaConfigureDialog::OllamaConfigureDialog(OllamaManager *manager, QWidget *pa
         mOllamaModelInstalledWidget->setEnabled(status);
     });
 
-    OllamaModelAvailableInfosManager managerModelInfosManager;
-    if (managerModelInfosManager.loadAvailableModels()) {
-        mOllamaModelWidget->setAvailableInfos(managerModelInfosManager.modelInfos());
-        mOllamaModelInstalledWidget->setAvailableInfos(managerModelInfosManager.modelInfos());
+    if (manager) {
+        mOllamaModelWidget->setAvailableInfos(manager->availableInfos());
     }
 
     const QString generalPageName = i18nc("@title Preferences page name", "General");
     auto configureGeneralWidgetPage = new KPageWidgetItem(mOllamaConfigureWidget, generalPageName);
     mOllamaConfigureWidget->setObjectName(u"mOllamaConfigureWidget"_s);
-    // configureGeneralWidgetPage->setIcon(QIcon::fromTheme(u"ruqola"_s));
     addPage(configureGeneralWidgetPage);
 
     const QString modelAvailablePageName = i18nc("@title Preferences page name", "Available Models");
     auto configureModelWidgetPage = new KPageWidgetItem(mOllamaModelWidget, modelAvailablePageName);
     mOllamaModelWidget->setObjectName(u"mOllamaModelWidget"_s);
-    // configureGeneralWidgetPage->setIcon(QIcon::fromTheme(u"ruqola"_s));
     addPage(configureModelWidgetPage);
 
     const QString modelInstalledPageName = i18nc("@title Preferences page name", "Installed Models");
     auto configureModelInstalledWidgetPage = new KPageWidgetItem(mOllamaModelInstalledWidget, modelInstalledPageName);
     mOllamaModelInstalledWidget->setObjectName(u"mOllamaModelInstalledWidget"_s);
-    // configureGeneralWidgetPage->setIcon(QIcon::fromTheme(u"ruqola"_s));
     addPage(configureModelInstalledWidgetPage);
 
     const QString modelCreatePageName = i18nc("@title Preferences page name", "Create Models");
     auto configureModelCreateWidgetPage = new KPageWidgetItem(mOllamaModelCreateWidget, modelCreatePageName);
     mOllamaModelCreateWidget->setObjectName(u"mOllamaModelCreateWidget"_s);
-    // configureGeneralWidgetPage->setIcon(QIcon::fromTheme(u"ruqola"_s));
     addPage(configureModelCreateWidgetPage);
 
     connect(buttonBox(), &QDialogButtonBox::accepted, this, &OllamaConfigureDialog::slotAccepted);
     readConfig();
+    auto okButton = button(QDialogButtonBox::StandardButton::Ok);
+    connect(mOllamaConfigureWidget, &OllamaConfigureWidget::enableOkButton, this, [okButton](bool state) {
+        okButton->setEnabled(state);
+    });
 }
 
 OllamaConfigureDialog::~OllamaConfigureDialog()
@@ -89,7 +87,7 @@ void OllamaConfigureDialog::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(400, 300));
-    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(myOllamaConfigureDialogGroupName));
+    const KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(myOllamaConfigureDialogGroupName));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
