@@ -17,7 +17,6 @@
 #include <KLocalizedString>
 #include <QFormLayout>
 #include <QLineEdit>
-#include <QPlainTextEdit>
 #include <QProcess>
 #include <QSpinBox>
 
@@ -26,7 +25,6 @@ OllamaConfigureWidget::OllamaConfigureWidget(OllamaManager *manager, QWidget *pa
     : QWidget{parent}
     , mName(new QLineEdit(this))
     , mServerUrl(new QLineEdit(this))
-    , mPrompt(new QPlainTextEdit(this))
     , mModelComboBoxWidget(new OllamaComboBoxWidget(this))
     , mMessageWidget(new TextAutoGenerateText::TextAutoGenerateNotWorkingMessageWidget(this))
     , mTemperature(new QDoubleSpinBox(this))
@@ -69,15 +67,11 @@ OllamaConfigureWidget::OllamaConfigureWidget(OllamaManager *manager, QWidget *pa
     mSeed->setRange(0, 10);
     mSeed->setSingleStep(1);
 
-    mPrompt->setObjectName(u"mPrompt"_s);
-    mainLayout->addRow(i18n("Prompt:"), mPrompt);
-    mPrompt->setPlaceholderText(i18n("No system prompt"));
-
     connect(mModelComboBoxWidget, &OllamaComboBoxWidget::reloadModel, this, &OllamaConfigureWidget::fillModels);
     connect(mManager, &OllamaManager::modelsLoadDone, this, [this](const OllamaManager::ModelsInfo &modelinfo) {
         // qDebug() << " OllamaConfigureWidget::fillModels() " << modelinfo;
         if (modelinfo.hasError) {
-            mMessageWidget->setText(modelinfo.errorOccured);
+            mMessageWidget->setMessageInfo(modelinfo.errorOccured);
             mMessageWidget->animatedShow();
             Q_EMIT ollamaProcessOk(false);
         } else {
@@ -85,6 +79,9 @@ OllamaConfigureWidget::OllamaConfigureWidget(OllamaManager *manager, QWidget *pa
             Q_EMIT ollamaProcessOk(true);
         }
     });
+    connect(mName, &QLineEdit::textChanged, this, [this](const QString &str) {
+        Q_EMIT enableOkButton(!str.trimmed().isEmpty());
+    });
     loadSettings();
     connect(mManager, &OllamaManager::refreshInstalledModels, this, &OllamaConfigureWidget::fillModels);
     fillModels();
@@ -106,7 +103,6 @@ void OllamaConfigureWidget::slotStartOllama()
     } else {
         mMessageWidget->animatedHide();
         Q_EMIT ollamaProcessOk(true);
-        // TODO activate it but we need to know that server is up. fillModels();
     }
 }
 
@@ -114,7 +110,6 @@ void OllamaConfigureWidget::loadSettings()
 {
     mName->setText(mManager->ollamaSettings()->displayName());
     mServerUrl->setText(mManager->ollamaSettings()->serverUrl().toString());
-    mPrompt->setPlainText(mManager->ollamaSettings()->systemPrompt());
     mModelComboBoxWidget->setCurrentModel(mManager->ollamaSettings()->currentModel());
     mTemperature->setValue(mManager->ollamaSettings()->temperature());
     mSeed->setValue(mManager->ollamaSettings()->seed());
@@ -123,7 +118,6 @@ void OllamaConfigureWidget::loadSettings()
 void OllamaConfigureWidget::saveSettings()
 {
     mManager->ollamaSettings()->setDisplayName(mName->text());
-    mManager->ollamaSettings()->setSystemPrompt(mPrompt->toPlainText());
     mManager->ollamaSettings()->setServerUrl(QUrl(mServerUrl->text()));
     mManager->ollamaSettings()->setCurrentModel(mModelComboBoxWidget->currentModel());
     mManager->ollamaSettings()->setTemperature(mTemperature->value());
