@@ -8,8 +8,6 @@
 #include <QWidget>
 class QLineEdit;
 class OllamaComboBoxWidget;
-class QPlainTextEdit;
-class KMessageWidget;
 class OllamaManager;
 class QDoubleSpinBox;
 class QSpinBox;
@@ -29,13 +27,13 @@ public:
 
 Q_SIGNALS:
     void ollamaProcessOk(bool status);
+    void enableOkButton(bool status);
 
 private:
     void fillModels();
     void slotStartOllama();
     QLineEdit *const mName;
     QLineEdit *const mServerUrl;
-    QPlainTextEdit *const mPrompt;
     OllamaComboBoxWidget *const mModelComboBoxWidget;
     TextAutoGenerateText::TextAutoGenerateNotWorkingMessageWidget *const mMessageWidget;
     QDoubleSpinBox *const mTemperature;
