@@ -9,14 +9,14 @@
 #include "autogeneratetext_ollama_debug.h"
 #include "autogeneratetext_ollama_generate_json_debug.h"
 #include "core/textautogenerateengineaccessmanager.h"
+#include "modelsmanager/ollamamodelavailableinfosmanager.h"
 #include "ollamareply.h"
 #include "ollamasettings.h"
 #include "ollamautils.h"
+#include <TextAutoGenerateText/TextAutoGenerateTextToolPluginManager>
 
 #include <KLocalizedString>
 
-#include <QBuffer>
-#include <QJsonArray>
 #include <QJsonDocument>
 #include <QJsonObject>
 #include <QNetworkReply>
@@ -27,6 +27,10 @@ OllamaManager::OllamaManager(OllamaSettings *settings, QObject *parent)
     : TextAutoGenerateText::TextAutoGenerateManagerBase{parent}
     , mOllamaSettings(settings)
 {
+    OllamaModelAvailableInfosManager managerModelInfosManager;
+    if (managerModelInfosManager.loadAvailableModels()) {
+        mAvailableInfos = managerModelInfosManager.modelInfos();
+    }
 }
 
 OllamaManager::~OllamaManager() = default;
@@ -168,7 +172,6 @@ void OllamaManager::loadModels()
             Q_EMIT modelsLoadDone(std::move(info));
             return;
         }
-
         ModelsInfo info;
         const auto json = QJsonDocument::fromJson(rep->readAll());
         const auto models = json["models"_L1].toArray();
@@ -178,6 +181,19 @@ void OllamaManager::loadModels()
             TextAutoGenerateText::TextAutoGenerateTextPlugin::ModelInfoNameAndIdentifier i;
             i.modelName = installed.generateModelName();
             i.identifier = installed.name();
+
+            QString installedName = installed.model();
+            const int position = installedName.indexOf(u':');
+            installedName = installedName.first(position);
+            auto matchesModelName = [&](const OllamaModelAvailableInfo &availableInfo) {
+                return availableInfo.name() == installedName;
+            };
+            auto it = std::find_if(mAvailableInfos.constBegin(), mAvailableInfos.constEnd(), matchesModelName);
+            if (it != mAvailableInfos.constEnd()) {
+                installed.setCategories((*it).categories());
+                installed.setLanguages((*it).languages());
+                installed.setModelUrl((*it).url());
+            }
             info.models.push_back(std::move(i));
             mInstalledInfos.append(std::move(installed));
         }
@@ -207,15 +223,14 @@ TextAutoGenerateText::TextAutoGenerateReply *OllamaManager::getCompletion(const
     QJsonObject data;
     // data["model"_L1] = request.model().isEmpty() ? m_models.constFirst() : request.model();
     data["prompt"_L1] = request.message();
-    data["model"_L1] = mOllamaSettings->currentModel();
-    const auto context = request.context().toJson();
-    if (!context.isNull()) {
-        data["context"_L1] = context;
-    }
+    data["model"_L1] = request.model();
+    // TODO add prompt here too
+#if 0
     if (!mOllamaSettings->systemPrompt().isEmpty()) {
         data["system"_L1] = mOllamaSettings->systemPrompt();
     }
-    qCDebug(AUTOGENERATETEXT_OLLAMA_GENERATE_JSON_LOG) << " JSon " << data;
+#endif
+    qCDebug(AUTOGENERATETEXT_OLLAMA_GENERATE_JSON_LOG) << " Json: " << data;
     auto reply = new OllamaReply{
         TextAutoGenerateText::TextAutoGenerateEngineAccessManager::self()->networkManager()->post(req, QJsonDocument(data).toJson(QJsonDocument::Compact)),
         OllamaReply::RequestTypes::StreamingGenerate,
@@ -231,23 +246,22 @@ TextAutoGenerateText::TextAutoGenerateReply *OllamaManager::getChatCompletion(co
     QNetworkRequest req{QUrl::fromUserInput(mOllamaSettings->serverUrl().toString() + OllamaUtils::chatPath())};
     req.setHeader(QNetworkRequest::ContentTypeHeader, u"application/json"_s);
     QJsonObject data;
-    data["model"_L1] = mOllamaSettings->currentModel();
+    data["model"_L1] = request.model();
     data["messages"_L1] = request.messages();
     data["temperature"_L1] = mOllamaSettings->temperature();
+    if (!request.tools().isEmpty()) {
+        data["tools"_L1] = TextAutoGenerateText::TextAutoGenerateTextToolPluginManager::self()->generateToolsArray(request.tools());
+    }
     if (mOllamaSettings->seed() != 0) {
         data["seed"_L1] = mOllamaSettings->seed();
     }
-    /*
-    if (!OllamaSettings::systemPrompt().isEmpty()) {
-        data["system"_L1] = OllamaSettings::systemPrompt();
-    }
-    */
-    qCDebug(AUTOGENERATETEXT_OLLAMA_GENERATE_JSON_LOG) << " JSon: " << data;
+    qDebug() << " OllamaManager::getChatCompletion json: " << data;
+    qCDebug(AUTOGENERATETEXT_OLLAMA_GENERATE_JSON_LOG) << " Json: " << data;
     auto reply = new OllamaReply{
         TextAutoGenerateText::TextAutoGenerateEngineAccessManager::self()->networkManager()->post(req, QJsonDocument(data).toJson(QJsonDocument::Compact)),
         OllamaReply::RequestTypes::StreamingChat,
         this};
-    connect(reply, &OllamaReply::finished, this, [this, reply] {
+    connect(reply, &OllamaReply::finished, this, [this, reply]() {
         Q_EMIT finished(reply->readResponse());
     });
     return reply;
@@ -273,6 +287,16 @@ OllamaSettings *OllamaManager::ollamaSettings() const
     return mOllamaSettings;
 }
 
+QList<OllamaModelAvailableInfo> OllamaManager::availableInfos() const
+{
+    return mAvailableInfos;
+}
+
+void OllamaManager::setAvailableInfos(const QList<OllamaModelAvailableInfo> &newAvailableInfos)
+{
+    mAvailableInfos = newAvailableInfos;
+}
+
 QDebug operator<<(QDebug d, const OllamaManager::CreateModelInfo &t)
 {
     d.space() << "modelName:" << t.modelName;
@@ -286,4 +310,31 @@ bool OllamaManager::CreateModelInfo::isValid() const
     return !modelName.isEmpty();
 }
 
+bool OllamaManager::hasVisionSupport(const QString &modelName) const
+{
+    return hasCategorySupport(modelName, TextAutoGenerateText::TextAutoGenerateManager::Category::Vision);
+}
+
+bool OllamaManager::hasToolsSupport(const QString &modelName) const
+{
+    return hasCategorySupport(modelName, TextAutoGenerateText::TextAutoGenerateManager::Category::Tools);
+}
+
+bool OllamaManager::hasCategorySupport(const QString &modelName, TextAutoGenerateText::TextAutoGenerateManager::Category cat) const
+{
+    if (modelName.isEmpty()) {
+        qCWarning(AUTOGENERATETEXT_OLLAMA_LOG) << " modelName is empty. it's a bug";
+        return false;
+    }
+    auto matchesModelName = [&](const OllamaModelInstalledInfo &info) {
+        return info.model() == modelName;
+    };
+    auto it = std::find_if(mInstalledInfos.constBegin(), mInstalledInfos.constEnd(), matchesModelName);
+    if (it == mInstalledInfos.constEnd()) {
+        qCWarning(AUTOGENERATETEXT_OLLAMA_LOG) << " modelName is not installed " << modelName;
+        return false;
+    }
+    return it->categories() & cat;
+}
+
 #include "moc_ollamamanager.cpp"
