@@ -5,6 +5,7 @@
 */
 
 #pragma once
+#include "modelsmanager/ollamamodelavailableinfo.h"
 #include "modelsmanager/ollamamodelinstalledinfo.h"
 #include "textautogenerateollama_export.h"
 #include <QDebug>
@@ -46,11 +47,19 @@ public:
 
     [[nodiscard]] OllamaSettings *ollamaSettings() const;
 
+    [[nodiscard]] QList<OllamaModelAvailableInfo> availableInfos() const;
+    void setAvailableInfos(const QList<OllamaModelAvailableInfo> &newAvailableInfos);
+
+    [[nodiscard]] bool hasVisionSupport(const QString &modelName) const;
+    [[nodiscard]] bool hasToolsSupport(const QString &modelName) const;
 Q_SIGNALS:
     void downloadInProgress(const QString &modelName, const TextAutoGenerateText::TextAutoGenerateReply::DownloadModelInfo &info);
 
 private:
+    [[nodiscard]] TEXTAUTOGENERATEOLLAMA_NO_EXPORT bool hasCategorySupport(const QString &modelName,
+                                                                           TextAutoGenerateText::TextAutoGenerateManager::Category cat) const;
     QList<OllamaModelInstalledInfo> mInstalledInfos;
+    QList<OllamaModelAvailableInfo> mAvailableInfos;
     OllamaSettings *const mOllamaSettings;
 };
 Q_DECLARE_TYPEINFO(OllamaManager::CreateModelInfo, Q_RELOCATABLE_TYPE);
