@@ -20,9 +20,9 @@ OllamaPlugin::OllamaPlugin(TextAutoGenerateText::TextAutoGenerateManager *manage
                            QObject *parent)
     : TextAutoGenerateText::TextAutoGenerateTextPlugin{manager, instance, parent}
     , mOllamaSettings(new OllamaSettings)
-    , mManager(new OllamaManager(mOllamaSettings, this))
+    , mOllamaManager(new OllamaManager(mOllamaSettings, this))
 {
-    connect(mManager, &OllamaManager::modelsLoadDone, this, [this](const OllamaManager::ModelsInfo &modelinfo) {
+    connect(mOllamaManager, &OllamaManager::modelsLoadDone, this, [this](const OllamaManager::ModelsInfo &modelinfo) {
         if (modelinfo.hasError) {
             setReady(false);
             Q_EMIT errorOccurred(modelinfo.errorOccured);
@@ -32,9 +32,16 @@ OllamaPlugin::OllamaPlugin(TextAutoGenerateText::TextAutoGenerateManager *manage
             setReady(true);
         }
     });
+    connect(mOllamaManager, &OllamaManager::downloadDone, this, &OllamaPlugin::downloadModelFinished);
+
     connect(manager, &TextAutoGenerateText::TextAutoGenerateManager::loadEngineDone, this, [this]() {
         if (this->manager()->textAutoGenerateTextInstancesManager()->isCurrentInstance(instanceUuid())) {
-            mManager->loadModels();
+            mOllamaManager->loadModels();
+        }
+    });
+    connect(mOllamaManager, &OllamaManager::finished, this, [this](const TextAutoGenerateText::TextAutoGenerateReply::Response &replyResponse) {
+        if (replyResponse.hasToolCallArguments()) {
+            Q_EMIT callTools(replyResponse.info);
         }
     });
 }
@@ -54,9 +61,6 @@ void OllamaPlugin::load(const KConfigGroup &config)
     if (config.hasKey(u"Temperature"_s)) {
         mOllamaSettings->setTemperature(config.readEntry(u"Temperature"_s, 0.8));
     }
-    if (config.hasKey(u"SystemPrompt"_s)) {
-        mOllamaSettings->setSystemPrompt(config.readEntry(u"SystemPrompt"_s));
-    }
     mOllamaSettings->setCurrentModel(config.readEntry(u"CurrentModel"_s));
 }
 
@@ -65,7 +69,6 @@ void OllamaPlugin::save(KConfigGroup &config)
     config.writeEntry(u"Name"_s, mOllamaSettings->displayName());
     config.writeEntry(u"Seed"_s, mOllamaSettings->seed());
     config.writeEntry(u"ServerUrl"_s, mOllamaSettings->serverUrl());
-    config.writeEntry(u"SystemPrompt"_s, mOllamaSettings->systemPrompt());
     config.writeEntry(u"Temperature"_s, mOllamaSettings->temperature());
     config.writeEntry(u"CurrentModel"_s, mOllamaSettings->currentModel());
 }
@@ -82,17 +85,12 @@ QString OllamaPlugin::translatedPluginName() const
 
 void OllamaPlugin::showConfigureDialog(QWidget *parentWidget)
 {
-    OllamaConfigureDialog d(mManager, parentWidget);
+    OllamaConfigureDialog d(mOllamaManager, parentWidget);
     if (d.exec()) {
         Q_EMIT configChanged();
     }
 }
 
-void OllamaPlugin::setPrompt(const QString &text)
-{
-    // TODO
-}
-
 QString OllamaPlugin::engineName() const
 {
     return "ollama"_L1;
@@ -103,7 +101,7 @@ void OllamaPlugin::askToAssistant(const QString &msg)
     TextAutoGenerateText::TextAutoGenerateTextRequest req;
     req.setMessage(msg);
     req.setModel(currentModel());
-    auto reply = mManager->getCompletion(req);
+    auto reply = mOllamaManager->getCompletion(req);
     const QByteArray uuid = QUuid::createUuid().toByteArray(QUuid::Id128);
     mConnections.insert(
         reply,
@@ -127,10 +125,8 @@ void OllamaPlugin::askToAssistant(const QString &msg)
 
 void OllamaPlugin::sendToAssistant(const SendToAssistantInfo &info)
 {
-    TextAutoGenerateText::TextAutoGenerateTextRequest req;
-    req.setModel(currentModel());
-    req.setMessages(info.messagesArray);
-    auto reply = mManager->getChatCompletion(req);
+    const TextAutoGenerateText::TextAutoGenerateTextRequest req = convertSendToAssistantInfoToTextRequest(info);
+    auto reply = mOllamaManager->getChatCompletion(req);
     const QByteArray messageUuid = info.messageUuid;
     const QByteArray chatId = info.chatId;
     mConnections.insert(
@@ -141,7 +137,12 @@ void OllamaPlugin::sendToAssistant(const SendToAssistantInfo &info)
     mConnections.insert(
         reply,
         QPair<QByteArray, QMetaObject::Connection>(messageUuid, connect(reply, &OllamaReply::finished, this, [reply, messageUuid, chatId, this] {
-                                                       manager()->changeInProgress(chatId, messageUuid, false);
+                                                       const auto response = reply->readResponse();
+                                                       if (response.hasToolCallArguments()) {
+                                                           manager()->callTools(chatId, messageUuid, response.info);
+                                                       } else {
+                                                           manager()->changeInProgress(chatId, messageUuid, false);
+                                                       }
                                                        qCDebug(AUTOGENERATETEXT_OLLAMA_PLUGIN_LOG) << " progress finished";
                                                        mConnections.remove(reply);
                                                        reply->deleteLater();
@@ -176,6 +177,17 @@ void OllamaPlugin::setCurrentModel(const QString &m)
 {
     mOllamaSettings->setCurrentModel(m);
     Q_EMIT configChanged();
+    Q_EMIT currentModelChanged();
+}
+
+bool OllamaPlugin::hasVisionSupport() const
+{
+    return mOllamaManager->hasVisionSupport(currentModel());
+}
+
+bool OllamaPlugin::hasToolsSupport() const
+{
+    return mOllamaManager->hasToolsSupport(currentModel());
 }
 
 #include "moc_ollamaplugin.cpp"
