@@ -20,7 +20,6 @@ OllamaReply::OllamaReply(QNetworkReply *netReply, RequestTypes requestType, QObj
         // that the request failed and we have no tokens to parse.
         if ((mRequestType == RequestTypes::StreamingGenerate || mRequestType == RequestTypes::StreamingChat) && !mTokens.empty()) {
             const auto finalResponse = mTokens.constLast();
-            mContext.setContextData(finalResponse["context"_L1].toArray());
             mInfo.totalDuration = std::chrono::nanoseconds{finalResponse["total_duration"_L1].toVariant().toULongLong()};
             mInfo.loadDuration = std::chrono::nanoseconds{finalResponse["load_duration"_L1].toVariant().toULongLong()};
             mInfo.promptEvalTokenCount = finalResponse["prompt_eval_count"_L1].toVariant().toULongLong();
@@ -73,6 +72,8 @@ OllamaReply::OllamaReply(QNetworkReply *netReply, RequestTypes requestType, QObj
             for (const auto &tok : std::as_const(completeTokens)) {
                 mTokens.append(QJsonDocument::fromJson(tok));
             }
+            // TODO parse "tool_calls"
+            // qDebug() << " mTokens " << mTokens;
             break;
         }
         case RequestTypes::StreamingGenerate:
@@ -94,11 +95,16 @@ OllamaReply::OllamaReply(QNetworkReply *netReply, RequestTypes requestType, QObj
     });
 }
 
-OllamaReply::~OllamaReply() = default;
-
-QString OllamaReply::readResponse() const
+OllamaReply::~OllamaReply()
 {
-    QString ret;
+    disconnect(mReply);
+    mReply->abort();
+    mReply->deleteLater();
+}
+
+TextAutoGenerateText::TextAutoGenerateReply::Response OllamaReply::readResponse() const
+{
+    TextAutoGenerateText::TextAutoGenerateReply::Response ret;
     switch (mRequestType) {
     case RequestTypes::DownloadModel:
     case RequestTypes::DeleteModel:
@@ -107,15 +113,21 @@ QString OllamaReply::readResponse() const
         break;
     case RequestTypes::StreamingChat:
         for (const auto &tok : mTokens) {
-            ret += tok["message"_L1]["content"_L1].toString();
+            if (tok["message"_L1].toObject().contains("tool_calls"_L1)) {
+                const QJsonArray array = tok["message"_L1]["tool_calls"_L1].toArray();
+                // qDebug() << " tool_calls: " << array;
+                const QList<TextAutoGenerateReply::ToolCallArgumentInfo> infos = parseToolCallsOllama(array);
+                // qDebug() << " QList<TextAutoGenerateReply::ToolCallArgumentInfo> infos " << infos;
+                ret.info.append(infos);
+            }
+            ret.response += tok["message"_L1]["content"_L1].toString();
         }
         break;
     case RequestTypes::Show:
-        // TODO
         break;
     case RequestTypes::StreamingGenerate:
         for (const auto &tok : mTokens) {
-            ret += tok["response"_L1].toString();
+            ret.response += tok["response"_L1].toString();
         }
     }
     return ret;
