@@ -8,7 +8,6 @@
 #include "textautogenerateollama_export.h"
 #include <QJsonDocument>
 #include <TextAutoGenerateText/TextAutoGenerateReply>
-#include <TextAutoGenerateText/TextAutoGenerateTextContext>
 #include <TextAutoGenerateText/TextAutoGenerateTextReplyInfo>
 
 class QNetworkReply;
@@ -37,7 +36,7 @@ public:
      *
      * @return The content that has been returned so far.
      */
-    [[nodiscard]] QString readResponse() const override;
+    [[nodiscard]] TextAutoGenerateText::TextAutoGenerateReply::Response readResponse() const override;
 
 private:
     [[nodiscard]] TEXTAUTOGENERATEOLLAMA_NO_EXPORT TextAutoGenerateText::TextAutoGenerateReply::DownloadModelInfo
