@@ -4,7 +4,6 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include "modelsmanager/ollamamodelavailableinfosmanager.h"
 #include "modelsmanager/ollamamodelavailablewidget.h"
 #include "ollamamanager.h"
 #include "ollamasettings.h"
@@ -14,19 +13,16 @@
 
 int main(int argc, char **argv)
 {
-    QApplication app(argc, argv);
+    const QApplication app(argc, argv);
     QStandardPaths::setTestModeEnabled(true);
     QCommandLineParser parser;
     parser.addVersionOption();
     parser.addHelpOption();
     parser.process(app);
-
-    auto manager = new OllamaManager(new OllamaSettings);
+    OllamaSettings settings;
+    auto manager = new OllamaManager(&settings);
     auto w = new OllamaModelAvailableWidget(manager);
-    OllamaModelAvailableInfosManager managerModelInfosManager;
-    if (managerModelInfosManager.loadAvailableModels()) {
-        w->setAvailableInfos(managerModelInfosManager.modelInfos());
-    }
+    w->setAvailableInfos(manager->availableInfos());
     w->resize(600, 400);
     w->show();
     app.exec();
