@@ -13,6 +13,7 @@ using namespace Qt::Literals::StringLiterals;
 #include <QVBoxLayout>
 #include <TextAutoGenerateText/TextAutoGenerateAskJob>
 #include <TextAutoGenerateText/TextAutoGenerateManager>
+#include <TextAutoGenerateText/TextAutoGenerateTextInstancesManagerDialog>
 
 TextAutoGenerateAskJobWidget::TextAutoGenerateAskJobWidget(QWidget *parent)
     : QWidget{parent}
@@ -23,8 +24,11 @@ TextAutoGenerateAskJobWidget::TextAutoGenerateAskJobWidget(QWidget *parent)
 
     auto lineEdit = new QLineEdit(this);
     hbox->addWidget(lineEdit);
-    auto button = new QPushButton(u"Ask"_s, this);
-    hbox->addWidget(button);
+    auto askButton = new QPushButton(u"Ask"_s, this);
+    hbox->addWidget(askButton);
+
+    auto configureButton = new QPushButton(u"Configure..."_s, this);
+    hbox->addWidget(configureButton);
 
     mainLayout->addLayout(hbox);
 
@@ -33,21 +37,30 @@ TextAutoGenerateAskJobWidget::TextAutoGenerateAskJobWidget(QWidget *parent)
 
     mainLayout->addWidget(plainTextEdit);
 
-    connect(button, &QPushButton::clicked, this, [this, lineEdit, plainTextEdit]() {
+    TextAutoGenerateText::TextAutoGenerateManager *manager = new TextAutoGenerateText::TextAutoGenerateManager(this);
+    manager->loadEngine();
+    connect(askButton, &QPushButton::clicked, this, [this, lineEdit, plainTextEdit, manager]() {
         if (const QString text = lineEdit->text(); !text.isEmpty()) {
-            TextAutoGenerateText::TextAutoGenerateManager *manager = new TextAutoGenerateText::TextAutoGenerateManager(this);
             TextAutoGenerateText::TextAutoGenerateAskJob *job = new TextAutoGenerateText::TextAutoGenerateAskJob(this);
             job->setText(text);
             job->setManager(manager);
             connect(job, &TextAutoGenerateText::TextAutoGenerateAskJob::generateTextDone, this, []() {
                 qDebug() << " generate text done ::::::::::";
             });
-            connect(job, &TextAutoGenerateText::TextAutoGenerateAskJob::generateTextInProgress, this, [plainTextEdit](const QString &str) {
-                plainTextEdit->setPlainText(str);
-            });
+            connect(job,
+                    &TextAutoGenerateText::TextAutoGenerateAskJob::generateTextInProgress,
+                    this,
+                    [plainTextEdit](const TextAutoGenerateText::TextAutoGenerateReply::Response &response) {
+                        plainTextEdit->setPlainText(response.response);
+                    });
             job->start();
         }
     });
+
+    connect(configureButton, &QPushButton::clicked, this, [this, manager]() {
+        TextAutoGenerateText::TextAutoGenerateTextInstancesManagerDialog dlg(manager, this);
+        dlg.exec();
+    });
 }
 
 TextAutoGenerateAskJobWidget::~TextAutoGenerateAskJobWidget() = default;
