@@ -7,11 +7,12 @@
 
 #include "textautogeneratetext_private_export.h"
 #include <QWidget>
-class QPushButton;
+class QToolButton;
 namespace TextAutoGenerateText
 {
 class TextAutoGenerateTextLineEdit;
 class TextAutoGenerateManager;
+class TextAutoGenerateToolsWidget;
 /**
  * @brief The TextAutoGenerateTextLineEditWidget class
  * @author Laurent Montel <montel@kde.org>
@@ -33,15 +34,21 @@ public:
     [[nodiscard]] QByteArray chatId() const;
     void setChatId(const QByteArray &newChatId);
 
+    void setActivatedTools(const QList<QByteArray> &lst);
+
 Q_SIGNALS:
-    void editingFinished(const QString &str, const QByteArray &uuid);
+    void editingFinished(const QString &str, const QByteArray &uuid, const QList<QByteArray> &lstTools);
     void keyPressed(QKeyEvent *ev);
 
 private:
     TEXTAUTOGENERATETEXT_NO_EXPORT void clearLineEdit();
     TEXTAUTOGENERATETEXT_NO_EXPORT void updateEnableState();
+    TEXTAUTOGENERATETEXT_NO_EXPORT void slotCurrentModelChanged();
     TextAutoGenerateTextLineEdit *const mTextAutoGenerateTextLineEdit;
-    QPushButton *const mSendMessage;
+    TextAutoGenerateToolsWidget *const mTextAutoGenerateToolsWidget;
+    QToolButton *const mSendMessage;
+    QToolButton *const mAttachFile;
+    QToolButton *const mConfigureTools;
     TextAutoGenerateText::TextAutoGenerateManager *const mManager;
     QByteArray mUuid;
 };
