@@ -8,7 +8,7 @@
 
 #include "core/models/textautogeneratemessagesmodel.h"
 #include "core/textautogeneratemanager.h"
-#include "widgets/textautogeneratetextmodelcombobox.h"
+#include "widgets/common/textautogeneratetextmodelcombobox.h"
 #include <KLocalizedString>
 #include <QHBoxLayout>
 #include <QToolButton>
@@ -45,24 +45,38 @@ TextAutoGenerateQuickAskHeaderWidget::TextAutoGenerateQuickAskHeaderWidget(TextA
     clearButton->setToolTip(i18nc("@info:tooltip", "Clear"));
     mainLayout->addWidget(clearButton);
 
+    auto saveQuickAskButton = new QToolButton(this);
+    saveQuickAskButton->setAutoRaise(true);
+    saveQuickAskButton->setObjectName(u"saveQuickAskButton"_s);
+    saveQuickAskButton->setIcon(QIcon::fromTheme(u"document-import"_s));
+    saveQuickAskButton->setToolTip(i18nc("@info:tooltip", "Save Discussion in Database"));
+    mainLayout->addWidget(saveQuickAskButton);
+
     QFont f = mModelInstanceLabel->font();
     f.setBold(true);
     f.setItalic(true);
     mModelInstanceLabel->setFont(f);
 
-    connect(clearButton, &QToolButton::clicked, this, [this]() {
-        if (auto messageModel = mManager->messagesModelFromChatId(mManager->currentChatId()); messageModel) {
-            messageModel->resetConversation();
-        }
-    });
-
     connect(configureButton, &QToolButton::clicked, this, &TextAutoGenerateQuickAskHeaderWidget::configureRequested);
-    connect(mManager, &TextAutoGenerateText::TextAutoGenerateManager::loadEngineDone, this, [this]() {
-        updateEngineModelName(mManager->generateEngineDisplayName());
-    });
-    connect(mModelComboBox, &TextAutoGenerateTextModelComboBox::activated, this, [this]() {
-        mManager->textAutoGeneratePlugin()->setCurrentModel(mModelComboBox->currentModel());
-    });
+    if (mManager) {
+        connect(clearButton, &QToolButton::clicked, this, [this]() {
+            if (!mManager->currentChatId().isEmpty()) {
+                if (auto messageModel = mManager->messagesModelFromChatId(mManager->currentChatId()); messageModel) {
+                    messageModel->resetConversation();
+                }
+            }
+        });
+
+        connect(mManager, &TextAutoGenerateText::TextAutoGenerateManager::loadEngineDone, this, [this]() {
+            updateEngineModelName(mManager->generateEngineDisplayName());
+        });
+        connect(mModelComboBox, &TextAutoGenerateTextModelComboBox::activated, this, [this]() {
+            mManager->textAutoGeneratePlugin()->setCurrentModel(mModelComboBox->currentModel());
+        });
+        connect(saveQuickAskButton, &QToolButton::clicked, this, [this]() {
+            mManager->saveCurrentChatInDataBase(mManager->currentChatId());
+        });
+    }
 }
 
 TextAutoGenerateQuickAskHeaderWidget::~TextAutoGenerateQuickAskHeaderWidget() = default;
