@@ -22,11 +22,11 @@ public:
     void editMessage(const QByteArray &uuid, const QString &messageStr);
 
 Q_SIGNALS:
-    void editingFinished(const QString &str, const QByteArray &uuid);
+    void editingFinished(const QString &str, const QByteArray &uuid, const QList<QByteArray> &lstTools);
     void configureChanged();
     void cancelRequested(const QByteArray &uuid);
-    void refreshAnswerRequested(const QByteArray &charId, const QModelIndex &index);
-    void editMessageRequested(const QModelIndex &index);
+    void refreshAnswerRequested(const QByteArray &charId, const QModelIndex &indexAnswer, const QList<QByteArray> &tools);
+    void editMessageRequested(const QModelIndex &index, const QList<QByteArray> &tools);
 
 private:
     TextAutoGenerateTextLineEditWidget *const mTextAutoGenerateTextLineWidget;
