@@ -22,10 +22,13 @@ TextAutoGenerateHistoryWidget::TextAutoGenerateHistoryWidget(TextAutoGenerateTex
     mainLayout->setContentsMargins({});
     mainLayout->setSpacing(0);
 
+    const auto shortcut = QKeySequence(Qt::CTRL | Qt::Key_K);
+
     mSearchLineEdit->setObjectName("mSearchLineEdit"_L1);
     mSearchLineEdit->setClearButtonEnabled(true);
     mSearchLineEdit->addAction(QIcon::fromTheme(u"view-filter"_s), QLineEdit::LeadingPosition);
-    mSearchLineEdit->setPlaceholderText(i18nc("@info:placeholder", "Search…"));
+    mSearchLineEdit->setPlaceholderText(i18nc("@info:placeholder", "Search… (%1)", shortcut.toString(QKeySequence::NativeText)));
+
     KLineEditEventHandler::catchReturnKey(mSearchLineEdit);
     mainLayout->addWidget(mSearchLineEdit);
 
@@ -34,6 +37,29 @@ TextAutoGenerateHistoryWidget::TextAutoGenerateHistoryWidget(TextAutoGenerateTex
 
     connect(mSearchLineEdit, &QLineEdit::textChanged, mTextAutoGenerateHistoryListView, &TextAutoGenerateHistoryListView::slotSearchTextChanged);
     connect(mTextAutoGenerateHistoryListView, &TextAutoGenerateHistoryListView::switchToChat, this, &TextAutoGenerateHistoryWidget::switchToChat);
+
+    auto searchRoomAction = new QAction(i18nc("@action", "Search Channels"), this);
+    searchRoomAction->setShortcut(shortcut);
+    connect(searchRoomAction, &QAction::triggered, this, [this]() {
+        mSearchLineEdit->setFocus();
+    });
+    addAction(searchRoomAction);
+
+    auto previousRoomAction = new QAction(i18nc("@action", "Previous Chat"), this);
+    previousRoomAction->setShortcut(Qt::CTRL | Qt::Key_Up);
+    connect(previousRoomAction, &QAction::triggered, this, [this]() {
+        mTextAutoGenerateHistoryListView->selectNextChat(TextAutoGenerateHistoryListView::Direction::Up);
+        mSearchLineEdit->clear();
+    });
+    addAction(previousRoomAction);
+
+    auto nextRoomAction = new QAction(i18nc("@action", "Next Chat"), this);
+    nextRoomAction->setShortcut(Qt::CTRL | Qt::Key_Down);
+    connect(nextRoomAction, &QAction::triggered, this, [this]() {
+        mTextAutoGenerateHistoryListView->selectNextChat(TextAutoGenerateHistoryListView::Direction::Down);
+        mSearchLineEdit->clear();
+    });
+    addAction(nextRoomAction);
 }
 
 TextAutoGenerateHistoryWidget::~TextAutoGenerateHistoryWidget() = default;
