@@ -5,6 +5,7 @@
 */
 
 #include "textautogeneratewidget.h"
+#include "core/textautogeneratechatsettings.h"
 using namespace Qt::Literals::StringLiterals;
 
 #include "core/models/textautogeneratemessagesmodel.h"
@@ -25,7 +26,6 @@ using namespace Qt::Literals::StringLiterals;
 #include <QKeyEvent>
 #include <QSplitter>
 #include <QVBoxLayout>
-#include <qtimer.h>
 
 using namespace TextAutoGenerateText;
 TextAutoGenerateWidget::TextAutoGenerateWidget(TextAutoGenerateText::TextAutoGenerateManager *manager, QWidget *parent)
@@ -61,15 +61,13 @@ TextAutoGenerateWidget::TextAutoGenerateWidget(TextAutoGenerateText::TextAutoGen
     mainLayout->addWidget(mTextAutoGenerateTextLineEditWidget);
     connect(mTextAutoGenerateTextLineEditWidget, &TextAutoGenerateTextLineEditWidget::editingFinished, this, &TextAutoGenerateWidget::slotEditingFinished);
 
-    connect(mHeaderWidget, &TextAutoGenerateHeaderWidget::configChanged, this, &TextAutoGenerateWidget::slotConfigureChanged);
-
     connect(mHeaderWidget, &TextAutoGenerateHeaderWidget::searchText, this, &TextAutoGenerateWidget::slotSearchText);
     if (mManager) {
         connect(mHeaderWidget, &TextAutoGenerateHeaderWidget::addNewChat, this, [this]() {
             mManager->createNewChat();
         });
         connect(mManager, &TextAutoGenerateManager::sendMessageRequested, this, [this](const QString &str) {
-            slotEditingFinished(str, {});
+            slotEditingFinished(str, {}, {}); // TODO use tools list ?
         });
 
         connect(mManager, &TextAutoGenerateManager::askMessageRequested, this, [this](const QString &str) {
@@ -89,8 +87,26 @@ TextAutoGenerateWidget::TextAutoGenerateWidget(TextAutoGenerateText::TextAutoGen
     connect(this, &TextAutoGenerateWidget::stopEditingMode, mTextAutoGenerateResultWidget, &TextAutoGenerateResultWidget::editingFinished);
     if (mManager) {
         connect(mHistoryWidget, &TextAutoGenerateHistoryWidget::switchToChat, this, [this](const QByteArray &chatId) {
+            const QString text = mTextAutoGenerateTextLineEditWidget->text();
+            const int position = mTextAutoGenerateResultWidget->scrollbarPosition();
+            if (text.isEmpty() && (position == mTextAutoGenerateResultWidget->scrollbarPositionMaximum())) {
+                mManager->textAutoGenerateChatSettings()->remove(mManager->currentChatId());
+            } else {
+                const TextAutoGenerateChatSettings::PendingTypedInfo chatSettingSave{
+                    .text = mTextAutoGenerateTextLineEditWidget->text(),
+                    .scrollbarPosition = mTextAutoGenerateResultWidget->scrollbarPosition(),
+                };
+                mManager->textAutoGenerateChatSettings()->add(mManager->currentChatId(), chatSettingSave);
+            }
             mManager->setCurrentChatId(chatId);
-            // TODO store info
+            const TextAutoGenerateChatSettings::PendingTypedInfo chatSettingRestore = mManager->textAutoGenerateChatSettings()->value(chatId);
+            if (chatSettingRestore.isValid()) {
+                mTextAutoGenerateTextLineEditWidget->setText(chatSettingRestore.text);
+                mTextAutoGenerateResultWidget->setScrollbarPosition(chatSettingRestore.scrollbarPosition);
+            } else {
+                mTextAutoGenerateTextLineEditWidget->setText({});
+                mTextAutoGenerateResultWidget->scrollToBottom();
+            }
         });
         connect(mManager->textAutoGenerateEngineLoader(), &TextAutoGenerateText::TextAutoGenerateEngineLoader::noPluginsFound, this, [this]() {
             Q_EMIT noPluginsFound(i18n("No plugin found."));
@@ -99,11 +115,12 @@ TextAutoGenerateWidget::TextAutoGenerateWidget(TextAutoGenerateText::TextAutoGen
             mManager->changeFavoriteHistory(mManager->currentChatId(), checked);
         });
 
-        connect(mManager, &TextAutoGenerateText::TextAutoGenerateManager::pluginsInitializedDone, this, &TextAutoGenerateWidget::slotInitializeDone);
         connect(mManager, &TextAutoGenerateText::TextAutoGenerateManager::errorOccured, this, &TextAutoGenerateWidget::slotAutogenerateFailed);
         connect(mManager, &TextAutoGenerateText::TextAutoGenerateManager::needToAddInstances, this, &TextAutoGenerateWidget::needToAddInstances);
         connect(mManager, &TextAutoGenerateText::TextAutoGenerateManager::pluginsInitializedDone, this, [this]() {
+            slotInitializeDone();
             mHeaderWidget->setModelList(mManager->textAutoGeneratePlugin()->models());
+            Q_EMIT pluginInitialized();
         });
     }
     readConfig();
@@ -138,14 +155,20 @@ void TextAutoGenerateWidget::writeConfig()
 {
     KConfigGroup group(KSharedConfig::openStateConfig(), u"TextAutoGenerateWidget"_s);
     group.writeEntry("mainSplitter", mSplitter->sizes());
+    if (mManager && !mManager->currentChatId().isEmpty()) {
+        group.writeEntry("currentChatId", mManager->currentChatId());
+    }
 }
 
 void TextAutoGenerateWidget::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), u"TextAutoGenerateWidget"_s);
+    const KConfigGroup group(KSharedConfig::openStateConfig(), u"TextAutoGenerateWidget"_s);
     const QList<int> size = {100, 400};
 
     mSplitter->setSizes(group.readEntry("mainSplitter", size));
+    if (mManager) {
+        mManager->switchToChatId(group.readEntry("currentChatId", QByteArray()));
+    }
 }
 
 QString TextAutoGenerateWidget::textLineEdit() const
@@ -161,18 +184,13 @@ void TextAutoGenerateWidget::loadEngine()
     }
 }
 
-void TextAutoGenerateWidget::slotConfigureChanged()
-{
-    loadEngine();
-}
-
-void TextAutoGenerateWidget::slotEditingFinished(const QString &str, const QByteArray &uuid)
+void TextAutoGenerateWidget::slotEditingFinished(const QString &str, const QByteArray &uuid, const QList<QByteArray> &lstTools)
 {
     mManager->checkCurrentChat();
     if (uuid.isEmpty()) {
-        mManager->textAutoGeneratePlugin()->sendMessage(mManager->currentChatId(), str);
+        mManager->textAutoGeneratePlugin()->sendMessage(mManager->currentChatId(), str, lstTools);
     } else {
-        mManager->textAutoGeneratePlugin()->editMessage(mManager->currentChatId(), uuid, str);
+        mManager->textAutoGeneratePlugin()->editMessage(mManager->currentChatId(), uuid, str, lstTools);
     }
     mTextAutoGenerateResultWidget->editingFinished(uuid);
 }
@@ -183,12 +201,13 @@ void TextAutoGenerateWidget::slotAutogenerateFailed(const QString &errorMessage)
     Q_EMIT pluginBroken(errorMessage);
 }
 
-void TextAutoGenerateWidget::slotEditMessage(const QModelIndex &index)
+void TextAutoGenerateWidget::slotEditMessage(const QModelIndex &index, const QList<QByteArray> &tools)
 {
     const QByteArray uuid = index.data(TextAutoGenerateMessagesModel::UuidRole).toByteArray();
     const QString messageStr = index.data(TextAutoGenerateMessagesModel::OriginalMessageRole).toString();
     mTextAutoGenerateTextLineEditWidget->setUuid(uuid);
     mTextAutoGenerateTextLineEditWidget->setText(messageStr);
+    mTextAutoGenerateTextLineEditWidget->setActivatedTools(tools);
 }
 
 void TextAutoGenerateWidget::slotCancelRequest(const QByteArray &uuid)
@@ -196,18 +215,17 @@ void TextAutoGenerateWidget::slotCancelRequest(const QByteArray &uuid)
     mManager->textAutoGeneratePlugin()->cancelRequest(uuid);
 }
 
-void TextAutoGenerateWidget::slotRefreshAnswer(const QByteArray &chatId, const QModelIndex &index)
+void TextAutoGenerateWidget::slotRefreshAnswer(const QByteArray &chatId, const QModelIndex &indexAnswer, const QList<QByteArray> &tools)
 {
-    const QByteArray uuid = index.data(TextAutoGenerateMessagesModel::UuidRole).toByteArray();
-    const QString messageStr = index.data(TextAutoGenerateMessagesModel::OriginalMessageRole).toString();
-    mManager->textAutoGeneratePlugin()->editMessage(chatId, uuid, messageStr);
+    const QByteArray uuid = indexAnswer.data(TextAutoGenerateMessagesModel::UuidRole).toByteArray();
+    const QString messageStr = indexAnswer.data(TextAutoGenerateMessagesModel::OriginalMessageRole).toString();
+    mManager->textAutoGeneratePlugin()->editMessage(chatId, uuid, messageStr, tools);
 }
 
 void TextAutoGenerateWidget::slotInitializeDone()
 {
-    mPluginWasInitialized = true;
     for (const auto &str : std::as_const(mAskMessageList)) {
-        slotEditingFinished(str, {});
+        slotEditingFinished(str, {}, {});
     }
     mAskMessageList.clear();
     mHeaderWidget->setModelList(mManager->textAutoGeneratePlugin()->models());
@@ -215,10 +233,10 @@ void TextAutoGenerateWidget::slotInitializeDone()
 
 void TextAutoGenerateWidget::slotAskMessageRequester(const QString &str)
 {
-    if (!mPluginWasInitialized) {
+    if (!mManager->pluginWasInitialized()) {
         mAskMessageList.append(str);
     } else {
-        slotEditingFinished(str, {});
+        slotEditingFinished(str, {}, {});
     }
 }
 
