@@ -12,7 +12,6 @@ namespace TextAutoGenerateText
 {
 class TextAutoGenerateResultWidget;
 class TextAutoGenerateTextLineEditWidget;
-class TextAutoGenerateMessage;
 class TextAutoGenerateManager;
 class TextAutoGenerateHistoryWidget;
 class TextAutoGenerateHeaderWidget;
@@ -38,19 +37,19 @@ Q_SIGNALS:
     void pluginBroken(const QString &msg);
     void stopEditingMode(const QByteArray &uuid);
     void needToAddInstances();
+    void pluginInitialized();
 
 private:
     TEXTAUTOGENERATETEXT_NO_EXPORT void slotInitializeDone();
-    TEXTAUTOGENERATETEXT_NO_EXPORT void slotEditingFinished(const QString &str, const QByteArray &uuid);
+    TEXTAUTOGENERATETEXT_NO_EXPORT void slotEditingFinished(const QString &str, const QByteArray &uuid, const QList<QByteArray> &lstTools);
     TEXTAUTOGENERATETEXT_NO_EXPORT void slotAutogenerateFailed(const QString &errorMessage);
     TEXTAUTOGENERATETEXT_NO_EXPORT void writeConfig();
     TEXTAUTOGENERATETEXT_NO_EXPORT void readConfig();
-    TEXTAUTOGENERATETEXT_NO_EXPORT void slotConfigureChanged();
     TEXTAUTOGENERATETEXT_NO_EXPORT void keyPressedInLineEdit(QKeyEvent *ev);
-    TEXTAUTOGENERATETEXT_NO_EXPORT void slotEditMessage(const QModelIndex &index);
+    TEXTAUTOGENERATETEXT_NO_EXPORT void slotEditMessage(const QModelIndex &index, const QList<QByteArray> &tools);
     TEXTAUTOGENERATETEXT_NO_EXPORT void slotCancelRequest(const QByteArray &uuid);
     TEXTAUTOGENERATETEXT_NO_EXPORT void slotAskMessageRequester(const QString &str);
-    TEXTAUTOGENERATETEXT_NO_EXPORT void slotRefreshAnswer(const QByteArray &chatId, const QModelIndex &index);
+    TEXTAUTOGENERATETEXT_NO_EXPORT void slotRefreshAnswer(const QByteArray &chatId, const QModelIndex &index, const QList<QByteArray> &tools);
     [[nodiscard]] TEXTAUTOGENERATETEXT_NO_EXPORT bool lineEditWidgetEnabledState() const;
 
     TextAutoGenerateResultWidget *const mTextAutoGenerateResultWidget;
@@ -60,7 +59,6 @@ private:
     TextAutoGenerateHistoryWidget *const mHistoryWidget;
     TextAutoGenerateHeaderWidget *const mHeaderWidget;
     QStringList mAskMessageList;
-    bool mPluginWasInitialized = false;
     TextAutoGenerateText::TextAutoGenerateManager *const mManager;
     QPointer<TextAutoGenerateSearchDialog> mSearchDialog;
 };
