@@ -4,21 +4,29 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "textautogeneratebaselistview.h"
-using namespace Qt::Literals::StringLiterals;
 
-#include "widgets/view/textautogeneratelistviewbasedelegate.h"
+#include "delegate/textautogeneratelistviewbasedelegate.h"
 #include <KLocalizedString>
 #include <QApplication>
 #include <QClipboard>
 #include <QMenu>
 #include <QMouseEvent>
 #include <QScrollBar>
+#include <TextAutoGenerateText/TextAutoGenerateManager>
+#include <TextAutoGenerateText/TextAutoGeneratePluginText>
+#include <TextAutoGenerateText/TextAutoGeneratePluginTextInterface>
+#include <TextAutoGenerateText/TextAutoGeneratePluginTextManager>
 
 using namespace TextAutoGenerateText;
+using namespace Qt::Literals::StringLiterals;
 TextAutoGenerateBaseListView::TextAutoGenerateBaseListView(TextAutoGenerateText::TextAutoGenerateManager *manager, QWidget *parent)
     : QListView(parent)
     , mManager(manager)
 {
+    if (mManager) {
+        connect(mManager, &TextAutoGenerateText::TextAutoGenerateManager::fontSizeChanged, this, &TextAutoGenerateBaseListView::slotFontChanged);
+    }
+
     setVerticalScrollMode(QAbstractItemView::ScrollPerPixel); // nicer in case of huge messages
     setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     setWordWrap(true); // so that the delegate sizeHint is called again when the width changes
@@ -29,15 +37,34 @@ TextAutoGenerateBaseListView::TextAutoGenerateBaseListView(TextAutoGenerateText:
     // Connect to rangeChanged rather than rowsInserted/rowsRemoved/modelReset.
     // This way it also catches the case of an item changing height (e.g. after async image loading)
     connect(verticalScrollBar(), &QScrollBar::rangeChanged, this, &TextAutoGenerateBaseListView::maybeScrollToBottom);
+    QList<TextAutoGeneratePluginText *> plugins = TextAutoGeneratePluginTextManager::self()->pluginsList();
+    if (plugins.count() > 1) {
+        std::sort(plugins.begin(), plugins.end(), [](TextAutoGeneratePluginText *left, TextAutoGeneratePluginText *right) {
+            return left->order() < right->order();
+        });
+    }
+    for (TextAutoGeneratePluginText *plugin : plugins) {
+        if (plugin->enabled()) {
+            /*
+            connect(plugin, &TextAutoGeneratePluginText::errorMessage, this, &MessageListViewBase::errorMessage);
+            connect(plugin, &TextAutoGeneratePluginText::successMessage, this, &MessageListViewBase::successMessage);
+*/
+            auto interface = plugin->createInterface(this);
+            mPluginTextInterface.append(interface);
+        }
+    }
 }
 
-TextAutoGenerateBaseListView::~TextAutoGenerateBaseListView() = default;
+TextAutoGenerateBaseListView::~TextAutoGenerateBaseListView()
+{
+    qDeleteAll(mPluginTextInterface);
+}
 
 void TextAutoGenerateBaseListView::contextMenuEvent(QContextMenuEvent *event)
 {
-    QMenu menu(this);
     const QModelIndex index = indexAt(event->pos());
     if (index.isValid()) {
+        QMenu menu(this);
         auto copyAction =
             new QAction(QIcon::fromTheme(u"edit-copy"_s), mDelegate->hasSelection() ? i18nc("@action", "Copy Selection") : i18nc("@action", "Copy"), &menu);
         copyAction->setShortcut(QKeySequence::Copy);
@@ -50,8 +77,9 @@ void TextAutoGenerateBaseListView::contextMenuEvent(QContextMenuEvent *event)
         auto copyUrlAction = [&]() -> QAction * {
             const QString url = mDelegate->urlAt(index, viewport()->mapFromGlobal(event->globalPos()));
             qDebug() << " url " << url;
-            if (url.isEmpty())
+            if (url.isEmpty()) {
                 return nullptr;
+            }
             auto action = new QAction(QIcon::fromTheme(u"edit-copy"_s), i18nc("@action", "Copy URL"), &menu);
             connect(action, &QAction::triggered, this, [url]() {
                 QGuiApplication::clipboard()->setText(url);
@@ -70,12 +98,23 @@ void TextAutoGenerateBaseListView::contextMenuEvent(QContextMenuEvent *event)
         });
         selectAllAction->setShortcut(QKeySequence::SelectAll);
         menu.addAction(selectAllAction);
-    }
-    if (!menu.actions().isEmpty()) {
+
+        if (mDelegate->hasSelection()) {
+            menu.addSeparator();
+            for (TextAutoGeneratePluginTextInterface *interface : std::as_const(mPluginTextInterface)) {
+                interface->setSelectedText(mDelegate->selectedText());
+                interface->addAction(&menu);
+            }
+        }
         menu.exec(event->globalPos());
     }
 }
 
+void TextAutoGenerateBaseListView::slotFontChanged()
+{
+    mDelegate->clearCache();
+}
+
 void TextAutoGenerateBaseListView::slotSelectAll(const QModelIndex &index)
 {
     mDelegate->selectAll(listViewOptions(), index);
