@@ -10,6 +10,7 @@ namespace TextAutoGenerateText
 {
 class TextAutoGenerateManager;
 class TextAutoGenerateListViewBaseDelegate;
+class TextAutoGeneratePluginTextInterface;
 class TextAutoGenerateBaseListView : public QListView
 {
     Q_OBJECT
@@ -41,9 +42,11 @@ protected:
     TextAutoGenerateListViewBaseDelegate *mDelegate = nullptr;
     TextAutoGenerateText::TextAutoGenerateManager *const mManager;
     QPoint mPressedPosition;
-    QPersistentModelIndex mCurrentIndex = {};
+    QPersistentModelIndex mCurrentIndex;
 
 private:
+    void slotFontChanged();
     bool mAtBottom = true;
+    QList<TextAutoGeneratePluginTextInterface *> mPluginTextInterface;
 };
 }
