@@ -13,15 +13,23 @@ namespace TextAutoGenerateText
 class TextAutoGenerateManager;
 class TextAutoGenerateHistoryListHeadingsProxyModel;
 class TextAutoGenerateHistorySortFilterProxyModel;
+class TextAutoGenerateHistoryListViewDelegate;
 class TEXTAUTOGENERATETEXT_TESTS_EXPORT TextAutoGenerateHistoryListView : public QTreeView
 {
     Q_OBJECT
 public:
+    enum class Direction : uint8_t {
+        Up,
+        Down,
+    };
     explicit TextAutoGenerateHistoryListView(TextAutoGenerateText::TextAutoGenerateManager *manager, QWidget *parent = nullptr);
     ~TextAutoGenerateHistoryListView() override;
 
     void slotSearchTextChanged(const QString &str);
 
+    void selectNextChat(Direction direction = Direction::Down);
+
+    [[nodiscard]] TextAutoGenerateHistorySortFilterProxyModel *filterModel() const;
 Q_SIGNALS:
     void switchToChat(const QByteArray &uuid);
 
@@ -31,6 +39,7 @@ protected:
     void paintEvent(QPaintEvent *event) override;
 
 private:
+    TEXTAUTOGENERATETEXT_NO_EXPORT void addWaitingAnswerAnimation(const QModelIndex &index);
     TEXTAUTOGENERATETEXT_NO_EXPORT void slotClicked(const QModelIndex &idx);
     TEXTAUTOGENERATETEXT_NO_EXPORT void slotShowArchived();
     TEXTAUTOGENERATETEXT_NO_EXPORT void slotCurrentChatIdChanged();
@@ -38,6 +47,7 @@ private:
     TextAutoGenerateHistorySortFilterProxyModel *const mHistoryProxyModel;
     TextAutoGenerateHistoryListHeadingsProxyModel *const mHistoryListHeadingsProxyModel;
     TextAutoGenerateText::TextAutoGenerateManager *const mManager;
+    TextAutoGenerateHistoryListViewDelegate *const mDelegate;
     QColor mTextColor;
 };
 }
