@@ -6,14 +6,11 @@
 #include "textautogeneratelistview.h"
 #include "core/models/textautogeneratemessagesmodel.h"
 #include "core/textautogeneratemanager.h"
-#include "textautogeneratelistviewdelegate.h"
+#include "delegate/textautogeneratelistviewdelegate.h"
 #include "textautogeneratemessagewaitingansweranimation.h"
 #include "textautogenerateselectedmessagebackgroundanimation.h"
 #include "textautogeneratetextwidget_animation_debug.h"
 #include <KLocalizedString>
-#include <KMessageBox>
-#include <QApplication>
-#include <QClipboard>
 #include <QMouseEvent>
 #include <QScrollBar>
 
@@ -53,9 +50,29 @@ void TextAutoGenerateListView::slotUpdateView()
 
 void TextAutoGenerateListView::slotEditMessage(const QModelIndex &index)
 {
-    auto model = const_cast<QAbstractItemModel *>(index.model());
+    clearEditingMode();
+    auto model = mManager->messagesModelFromChatId(mManager->currentChatId());
     model->setData(index, true, TextAutoGenerateMessagesModel::EditingRole);
-    Q_EMIT editMessageRequested(index);
+
+    const QByteArray anwserUuid = index.data(TextAutoGenerateMessagesModel::AnswerUuidRole).toByteArray();
+    mMessageIdBeingEdited = index.data(TextAutoGenerateMessagesModel::UuidRole).toByteArray();
+    const QModelIndex anwseridx = model->indexForUuid(anwserUuid);
+    const QList<QByteArray> tools = anwseridx.data(TextAutoGenerateMessagesModel::ToolsRole).value<QList<QByteArray>>();
+    Q_EMIT editMessageRequested(index, tools);
+}
+
+void TextAutoGenerateListView::clearEditingMode()
+{
+    if (mMessageIdBeingEdited.isEmpty()) {
+        return;
+    }
+    // Remove old mark as editing
+    auto model = mManager->messagesModelFromChatId(mManager->currentChatId());
+
+    const QModelIndex index = model->indexForUuid(mMessageIdBeingEdited);
+    if (index.isValid()) {
+        model->setData(index, false, TextAutoGenerateMessagesModel::EditingRole);
+    }
 }
 
 void TextAutoGenerateListView::slotCancelRequested(const QModelIndex &index)
@@ -80,11 +97,13 @@ void TextAutoGenerateListView::slotRemoveRequested(const QModelIndex &index)
 void TextAutoGenerateListView::slotRefreshRequested(const QModelIndex &index)
 {
     const QByteArray uuid = index.data(TextAutoGenerateMessagesModel::UuidRole).toByteArray();
+
     if (!uuid.isEmpty()) {
+        const QList<QByteArray> tools = index.data(TextAutoGenerateMessagesModel::ToolsRole).value<QList<QByteArray>>();
         const QByteArray chatId = mManager->currentChatId();
-        const QModelIndex index = mManager->refreshAnswer(chatId, uuid);
-        if (index.isValid()) {
-            Q_EMIT refreshAnswerRequested(chatId, index);
+        const QModelIndex indexAnswer = mManager->refreshAnswer(chatId, uuid);
+        if (indexAnswer.isValid()) {
+            Q_EMIT refreshAnswerRequested(chatId, indexAnswer, tools);
         }
     }
 }
@@ -171,6 +190,7 @@ void TextAutoGenerateListView::editingFinished(const QByteArray &uuid)
         if (idx.isValid()) {
             auto lastModel = const_cast<QAbstractItemModel *>(idx.model());
             lastModel->setData(idx, false, TextAutoGenerateMessagesModel::EditingRole);
+            mMessageIdBeingEdited.clear();
         }
     }
 }
@@ -179,7 +199,6 @@ void TextAutoGenerateListView::slotCurrentChatIdChanged()
 {
     auto model = mManager->messagesModelFromChatId(mManager->currentChatId());
     setModel(model);
-    // TODO get info
     static_cast<TextAutoGenerateListViewDelegate *>(mDelegate)->setInProgress(mManager->chatInProgress(mManager->currentChatId()));
 }
 
@@ -189,7 +208,7 @@ void TextAutoGenerateListView::addWaitingAnswerAnimation(const QModelIndex &inde
     animation->setModelIndex(index);
     const QMetaObject::Connection valueChangeConnection =
         connect(animation, &TextAutoGenerateMessageWaitingAnswerAnimation::valueChanged, this, [this, animation]() {
-            qCDebug(TEXTAUTOGENERATETEXT_WIDGET_ANIMATION_LOG) << "TextAutoGenerateMessageWaitingAnswerAnimation start";
+            qCDebug(TEXTAUTOGENERATETEXT_WIDGET_ANIMATION_LOG) << "TextAutoGenerateMessageWaitingAnswerAnimation value changed";
             static_cast<TextAutoGenerateListViewDelegate *>(mDelegate)->needUpdateWaitingAnswerAnimation(animation->modelIndex(), animation->scaleOpacities());
             update(animation->modelIndex());
         });
@@ -221,6 +240,7 @@ void TextAutoGenerateListView::addSelectedMessageBackgroundAnimation(const QMode
 
 void TextAutoGenerateListView::setModel(QAbstractItemModel *newModel)
 {
+    clearEditingMode();
     const QAbstractItemModel *oldModel = model();
     if (oldModel) {
         disconnect(oldModel, nullptr, this, nullptr);
@@ -236,7 +256,7 @@ void TextAutoGenerateListView::setModel(QAbstractItemModel *newModel)
         connect(verticalScrollBar(), &QScrollBar::rangeChanged, this, &TextAutoGenerateListView::maybeScrollToBottom);
 
         connect(newModel, &QAbstractItemModel::dataChanged, this, [this](const QModelIndex &topLeft, const QModelIndex &, const QList<int> &roles) {
-            if (roles.contains(TextAutoGenerateMessagesModel::MessageRole) || roles.contains(TextAutoGenerateMessagesModel::FinishedRole)) {
+            if (roles.contains(TextAutoGenerateMessagesModel::MessageHtmlGeneratedRole) || roles.contains(TextAutoGenerateMessagesModel::FinishedRole)) {
                 const QByteArray uuid = topLeft.data(TextAutoGenerateMessagesModel::UuidRole).toByteArray();
                 if (!uuid.isEmpty()) {
                     mDelegate->removeMessageCache(uuid);
