@@ -6,7 +6,6 @@
 #pragma once
 #include "textautogeneratebaselistview.h"
 #include "textautogeneratetext_private_export.h"
-#include <QListView>
 namespace TextAutoGenerateText
 {
 class TextAutoGenerateManager;
@@ -30,9 +29,9 @@ protected:
     [[nodiscard]] QString originalMessage(const QModelIndex &index) const override;
 
 Q_SIGNALS:
-    void editMessageRequested(const QModelIndex &index);
+    void editMessageRequested(const QModelIndex &index, const QList<QByteArray> &tools);
     void cancelRequested(const QByteArray &uuid);
-    void refreshAnswerRequested(const QByteArray &chatId, const QModelIndex &index);
+    void refreshAnswerRequested(const QByteArray &chatId, const QModelIndex &indexAnswer, const QList<QByteArray> &tools);
 
 private:
     TEXTAUTOGENERATETEXT_NO_EXPORT void handleMouseEvent(QMouseEvent *event) override;
@@ -46,5 +45,7 @@ private:
     TEXTAUTOGENERATETEXT_NO_EXPORT void slotUpdateView();
     TEXTAUTOGENERATETEXT_NO_EXPORT void goToMessageId(const QByteArray &uuid);
     TEXTAUTOGENERATETEXT_NO_EXPORT void slotRemoveRequested(const QModelIndex &index);
+    TEXTAUTOGENERATETEXT_NO_EXPORT void clearEditingMode();
+    QByteArray mMessageIdBeingEdited;
 };
 }
