@@ -20,8 +20,16 @@ public:
 
     void setSearchMessages(const QList<TextAutoGenerateSearchMessage> &msgs);
 
+protected:
+    void paintEvent(QPaintEvent *event) override;
+    [[nodiscard]] bool event(QEvent *ev) override;
+
+    [[nodiscard]] QString originalMessage(const QModelIndex &index) const override;
+
 private:
     TEXTAUTOGENERATETEXT_NO_EXPORT void slotGoToMessage(const QString &link);
+    TEXTAUTOGENERATETEXT_NO_EXPORT void generalPaletteChanged();
+    QColor mTextColor;
     TextAutoGenerateSearchMessagesModel *const mModel;
 };
 }
