@@ -251,10 +251,8 @@ bool PlainTextEditor::emojiSupport() const
     return d->supportFeatures & Emoji;
 }
 
-void PlainTextEditor::addExtraMenuEntry(QMenu *menu, QPoint pos)
+void PlainTextEditor::addExtraMenuEntry([[maybe_unused]] QMenu *menu, [[maybe_unused]] QPoint pos)
 {
-    Q_UNUSED(menu)
-    Q_UNUSED(pos)
 }
 
 void PlainTextEditor::slotSpeakText()
@@ -321,7 +319,7 @@ void PlainTextEditor::setSpellCheckingSupport(bool check)
     }
 }
 
-void PlainTextEditor::setWebShortcutSupport(bool b)
+void PlainTextEditor::setWebShortcutSupport([[maybe_unused]] bool b)
 {
 #if HAVE_KTEXTADDONS_KIO_SUPPORT
     if (b) {
@@ -329,8 +327,6 @@ void PlainTextEditor::setWebShortcutSupport(bool b)
     } else {
         d->supportFeatures = (d->supportFeatures & ~AllowWebShortcut);
     }
-#else
-    Q_UNUSED(b);
 #endif
 }
 
@@ -370,7 +366,7 @@ void PlainTextEditor::setReadOnly(bool readOnly)
     } else {
         if (d->customPalette && testAttribute(Qt::WA_SetPalette)) {
             QPalette p = palette();
-            QColor color = p.color(QPalette::Normal, QPalette::Base);
+            const QColor color = p.color(QPalette::Normal, QPalette::Base);
             p.setColor(QPalette::Base, color);
             p.setColor(QPalette::Window, color);
             setPalette(p);
@@ -725,10 +721,10 @@ void PlainTextEditor::moveLineUpDown(bool moveUp)
         }
     }
 
-    int start = move.position();
+    const int start = move.position();
     move.clearSelection();
     move.insertText(text);
-    int end = move.position();
+    const int end = move.position();
 
     if (hasSelection) {
         move.setPosition(end);
