@@ -278,6 +278,7 @@ QMenu *RichTextEditor::mousePopupMenu(QPoint pos)
         }
 #if HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
         if (!emptyDocument) {
+            popup->addSeparator();
             QAction *speakAction = popup->addAction(i18n("Speak Text"));
             speakAction->setIcon(QIcon::fromTheme(u"preferences-desktop-text-to-speech"_s));
             connect(speakAction, &QAction::triggered, this, &RichTextEditor::slotSpeakText);
@@ -319,7 +320,7 @@ void RichTextEditor::slotSpeakText()
     Q_EMIT say(text);
 }
 
-void RichTextEditor::setWebShortcutSupport(bool b)
+void RichTextEditor::setWebShortcutSupport([[maybe_unused]] bool b)
 {
 #if HAVE_KTEXTADDONS_KIO_SUPPORT
     if (b) {
@@ -327,8 +328,6 @@ void RichTextEditor::setWebShortcutSupport(bool b)
     } else {
         d->supportFeatures = (d->supportFeatures & ~AllowWebShortcut);
     }
-#else
-    Q_UNUSED(b);
 #endif
 }
 
@@ -361,9 +360,8 @@ void RichTextEditor::addIgnoreWords(const QStringList &lst)
     addIgnoreWordsToHighLighter();
 }
 
-void RichTextEditor::forceAutoCorrection(bool selectedText)
+void RichTextEditor::forceAutoCorrection([[maybe_unused]] bool selectedText)
 {
-    Q_UNUSED(selectedText)
     // Nothing here
 }
 
@@ -381,6 +379,20 @@ bool RichTextEditor::searchSupport() const
     return d->supportFeatures & Search;
 }
 
+bool RichTextEditor::quickTextFormat() const
+{
+    return d->supportFeatures & QuickTextFormat;
+}
+
+void RichTextEditor::setQuickTextFormat(bool b)
+{
+    if (b) {
+        d->supportFeatures |= QuickTextFormat;
+    } else {
+        d->supportFeatures = (d->supportFeatures & ~QuickTextFormat);
+    }
+}
+
 void RichTextEditor::setAllowTabSupport(bool b)
 {
     if (b) {
@@ -438,10 +450,8 @@ void RichTextEditor::slotAllowTab()
     setTabChangesFocus(!tabChangesFocus());
 }
 
-void RichTextEditor::addExtraMenuEntry(QMenu *menu, QPoint pos)
+void RichTextEditor::addExtraMenuEntry([[maybe_unused]] QMenu *menu, [[maybe_unused]] QPoint pos)
 {
-    Q_UNUSED(menu)
-    Q_UNUSED(pos)
 }
 
 void RichTextEditor::slotUndoableClear()
