@@ -5,6 +5,8 @@
 */
 
 #include "textfindwidgettest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "widgets/textfindreplacewidget.h"
 #include <QPushButton>
 #include <QTest>
@@ -21,19 +23,19 @@ void TextFindWidgetTest::shouldHaveDefaultValues()
     QVERIFY(!w.isRegularExpression());
     QVERIFY(w.searchText().isEmpty());
 
-    auto mFindNextBtn = w.findChild<QPushButton *>(QStringLiteral("mFindNextBtn"));
+    auto mFindNextBtn = w.findChild<QPushButton *>(u"mFindNextBtn"_s);
     QVERIFY(mFindNextBtn);
     QVERIFY(!mFindNextBtn->text().isEmpty());
     QVERIFY(!mFindNextBtn->toolTip().isEmpty());
     QVERIFY(!mFindNextBtn->isEnabled());
 
-    auto mFindPrevBtn = w.findChild<QPushButton *>(QStringLiteral("mFindPrevBtn"));
+    auto mFindPrevBtn = w.findChild<QPushButton *>(u"mFindPrevBtn"_s);
     QVERIFY(mFindPrevBtn);
     QVERIFY(!mFindPrevBtn->text().isEmpty());
     QVERIFY(!mFindPrevBtn->toolTip().isEmpty());
     QVERIFY(!mFindPrevBtn->isEnabled());
 
-    auto optionsBtn = w.findChild<QPushButton *>(QStringLiteral("optionsBtn"));
+    auto optionsBtn = w.findChild<QPushButton *>(u"optionsBtn"_s);
     QVERIFY(optionsBtn);
     QVERIFY(!optionsBtn->text().isEmpty());
     QVERIFY(!optionsBtn->toolTip().isEmpty());
