@@ -5,6 +5,8 @@
 */
 
 #include "texttospeechconfigwidgettest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "texttospeechconfiginterface.h"
 #include "texttospeechconfigwidget.h"
 #include "texttospeechlanguagecombobox.h"
@@ -35,27 +37,27 @@ void TextToSpeechConfigWidgetTest::shouldHaveDefaultValue()
 {
     TextEditTextToSpeech::TextToSpeechConfigWidget textToSpeechConfigWidget;
     addInterface(&textToSpeechConfigWidget);
-    auto volume = textToSpeechConfigWidget.findChild<TextEditTextToSpeech::TextToSpeechSliderWidget *>(QStringLiteral("volume"));
+    auto volume = textToSpeechConfigWidget.findChild<TextEditTextToSpeech::TextToSpeechSliderWidget *>(u"volume"_s);
     QVERIFY(volume);
 
-    auto rate = textToSpeechConfigWidget.findChild<TextEditTextToSpeech::TextToSpeechSliderWidget *>(QStringLiteral("rate"));
+    auto rate = textToSpeechConfigWidget.findChild<TextEditTextToSpeech::TextToSpeechSliderWidget *>(u"rate"_s);
     QVERIFY(rate);
 
-    auto pitch = textToSpeechConfigWidget.findChild<TextEditTextToSpeech::TextToSpeechSliderWidget *>(QStringLiteral("pitch"));
+    auto pitch = textToSpeechConfigWidget.findChild<TextEditTextToSpeech::TextToSpeechSliderWidget *>(u"pitch"_s);
     QVERIFY(pitch);
 
-    auto language = textToSpeechConfigWidget.findChild<TextEditTextToSpeech::TextToSpeechLanguageComboBox *>(QStringLiteral("language"));
+    auto language = textToSpeechConfigWidget.findChild<TextEditTextToSpeech::TextToSpeechLanguageComboBox *>(u"language"_s);
     QVERIFY(language);
     // FIXME
     // QVERIFY(language->count()>0);
 
-    auto availableEngine = textToSpeechConfigWidget.findChild<QComboBox *>(QStringLiteral("engine"));
+    auto availableEngine = textToSpeechConfigWidget.findChild<QComboBox *>(u"engine"_s);
     QVERIFY(availableEngine);
 
-    auto voice = textToSpeechConfigWidget.findChild<TextEditTextToSpeech::TextToSpeechVoiceComboBox *>(QStringLiteral("voice"));
+    auto voice = textToSpeechConfigWidget.findChild<TextEditTextToSpeech::TextToSpeechVoiceComboBox *>(u"voice"_s);
     QVERIFY(voice);
 
-    auto mTestButton = textToSpeechConfigWidget.findChild<QPushButton *>(QStringLiteral("mTestButton"));
+    auto mTestButton = textToSpeechConfigWidget.findChild<QPushButton *>(u"mTestButton"_s);
     QVERIFY(mTestButton);
 }
 
@@ -64,28 +66,28 @@ void TextToSpeechConfigWidgetTest::shouldEmitConfigChangedWhenChangeConfigValue(
     TextEditTextToSpeech::TextToSpeechConfigWidget textToSpeechConfigWidget;
     addInterface(&textToSpeechConfigWidget);
     QSignalSpy spy(&textToSpeechConfigWidget, &TextEditTextToSpeech::TextToSpeechConfigWidget::configChanged);
-    auto volume = textToSpeechConfigWidget.findChild<TextEditTextToSpeech::TextToSpeechSliderWidget *>(QStringLiteral("volume"));
+    auto volume = textToSpeechConfigWidget.findChild<TextEditTextToSpeech::TextToSpeechSliderWidget *>(u"volume"_s);
     volume->setValue(5);
     // It updates slider too! => 2 emit signal.
     QCOMPARE(spy.count(), 2);
 
     spy.clear();
-    auto rate = textToSpeechConfigWidget.findChild<TextEditTextToSpeech::TextToSpeechSliderWidget *>(QStringLiteral("rate"));
+    auto rate = textToSpeechConfigWidget.findChild<TextEditTextToSpeech::TextToSpeechSliderWidget *>(u"rate"_s);
     rate->setValue(5);
     QCOMPARE(spy.count(), 2);
 
     spy.clear();
-    auto pitch = textToSpeechConfigWidget.findChild<TextEditTextToSpeech::TextToSpeechSliderWidget *>(QStringLiteral("pitch"));
+    auto pitch = textToSpeechConfigWidget.findChild<TextEditTextToSpeech::TextToSpeechSliderWidget *>(u"pitch"_s);
     pitch->setValue(5);
     QCOMPARE(spy.count(), 2);
 
-    auto language = textToSpeechConfigWidget.findChild<QComboBox *>(QStringLiteral("language"));
+    auto language = textToSpeechConfigWidget.findChild<QComboBox *>(u"language"_s);
     language->blockSignals(true);
     QStringList lst;
-    lst << QStringLiteral("foo");
-    lst << QStringLiteral("foo");
-    lst << QStringLiteral("foo");
-    lst << QStringLiteral("foo");
+    lst << u"foo"_s;
+    lst << u"foo"_s;
+    lst << u"foo"_s;
+    lst << u"foo"_s;
     language->addItems(lst);
     language->blockSignals(false);
     language->setCurrentIndex(3);
