@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -25,21 +25,22 @@ public:
 
     ~TextToSpeech() override;
 
-    Q_REQUIRED_RESULT bool isReady() const;
+    [[nodiscard]] bool isReady() const;
 
     enum State {
         Ready = 0,
         Speaking,
         Paused,
         BackendError,
+        Synthesizing,
     };
 
-    Q_REQUIRED_RESULT double volume() const;
-    Q_REQUIRED_RESULT QVector<QLocale> availableLocales() const;
-    Q_REQUIRED_RESULT QStringList availableEngines() const;
-    Q_REQUIRED_RESULT QStringList availableVoices() const;
+    [[nodiscard]] double volume() const;
+    [[nodiscard]] QVector<QLocale> availableLocales() const;
+    [[nodiscard]] QStringList availableEngines() const;
+    [[nodiscard]] QStringList availableVoices() const;
 
-    Q_REQUIRED_RESULT QLocale locale() const;
+    [[nodiscard]] QLocale locale() const;
 
     void reloadSettings();
 public Q_SLOTS:
