@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -24,11 +24,11 @@ public:
     explicit TextToSpeechActions(QObject *parent = nullptr);
     ~TextToSpeechActions() override;
 
-    Q_REQUIRED_RESULT QAction *stopAction() const;
+    [[nodiscard]] QAction *stopAction() const;
 
-    Q_REQUIRED_RESULT QAction *playPauseAction() const;
+    [[nodiscard]] QAction *playPauseAction() const;
 
-    Q_REQUIRED_RESULT TextToSpeechWidget::State state() const;
+    [[nodiscard]] TextToSpeechWidget::State state() const;
 
 public Q_SLOTS:
     void setState(TextToSpeechWidget::State);
