@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2023-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -16,11 +16,8 @@ public:
     explicit TextToSpeechVoiceComboBox(QWidget *parent = nullptr);
     ~TextToSpeechVoiceComboBox() override;
 
-    Q_REQUIRED_RESULT QVoice currentVoice() const;
+    [[nodiscard]] QVoice currentVoice() const;
     void setCurrentVoice(const QVoice &voice);
     void updateVoices(const QVector<QVoice> &voices);
 };
 }
-#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
-Q_DECLARE_METATYPE(QVoice)
-#endif
