@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2023-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,9 +8,7 @@
 #include "emoticonunicodeutils.h"
 
 using namespace TextEmoticonsCore;
-CustomEmoji::CustomEmoji()
-{
-}
+CustomEmoji::CustomEmoji() = default;
 
 QString CustomEmoji::identifier() const
 {
@@ -37,6 +35,16 @@ void CustomEmoji::setIsAnimatedEmoji(bool newIsAnimatedEmoji)
     mIsAnimatedEmoji = newIsAnimatedEmoji;
 }
 
+QString CustomEmoji::fileName() const
+{
+    return mFileName;
+}
+
+void CustomEmoji::setFileName(const QString &newFileName)
+{
+    mFileName = newFileName;
+}
+
 QDebug operator<<(QDebug d, const CustomEmoji &t)
 {
     d << "Identifier " << t.identifier();
