@@ -18,15 +18,15 @@ using namespace TextEmoticonsCore;
 class TextEmoticonsCore::UnicodeEmoticonManagerPrivate
 {
 public:
-    void loadUnicodeEmoji();
+    void loadUnicodeEmoji(const QString &filename = {});
     [[nodiscard]] QString i18nUnicodeCategory(const QString &name) const;
     QList<UnicodeEmoticon> unicodeEmojiList;
 };
 
-void UnicodeEmoticonManagerPrivate::loadUnicodeEmoji()
+void UnicodeEmoticonManagerPrivate::loadUnicodeEmoji(const QString &filename)
 {
-    UnicodeEmoticonParser unicodeParser;
-    QFile file(u":/emoji.json"_s);
+    const UnicodeEmoticonParser unicodeParser;
+    QFile file(filename.isEmpty() ? u":/emoji.json"_s : filename);
     if (!file.open(QFile::ReadOnly)) {
         qCWarning(TEXTEMOTICONSCORE_LOG) << "Impossible to open file: " << file.errorString();
         return;
@@ -64,18 +64,18 @@ QString UnicodeEmoticonManagerPrivate::i18nUnicodeCategory(const QString &name)
     return {};
 }
 
-UnicodeEmoticonManager::UnicodeEmoticonManager(QObject *parent)
+UnicodeEmoticonManager::UnicodeEmoticonManager(const QString &filename, QObject *parent)
     : QObject(parent)
     , d(new TextEmoticonsCore::UnicodeEmoticonManagerPrivate)
 {
-    d->loadUnicodeEmoji();
+    d->loadUnicodeEmoji(filename);
 }
 
 UnicodeEmoticonManager::~UnicodeEmoticonManager() = default;
 
-UnicodeEmoticonManager *UnicodeEmoticonManager::self()
+UnicodeEmoticonManager *UnicodeEmoticonManager::self(const QString &filename)
 {
-    static UnicodeEmoticonManager s_self;
+    static UnicodeEmoticonManager s_self(filename);
     return &s_self;
 }
 
