@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -21,7 +21,7 @@ public:
     UnicodeEmoticonParser();
     ~UnicodeEmoticonParser();
 
-    Q_REQUIRED_RESULT QList<UnicodeEmoticon> parse(const QJsonObject &o) const;
-    Q_REQUIRED_RESULT static int changeOrder(const QString &name);
+    [[nodiscard]] QList<UnicodeEmoticon> parse(const QJsonObject &o) const;
+    [[nodiscard]] static int changeOrder(const QString &name);
 };
 }
