@@ -8,9 +8,9 @@
 #include "emoticontexteditselector.h"
 using namespace Qt::Literals::StringLiterals;
 
-#include "emoticoncategorybuttons.h"
-#include "emoticonlistview.h"
-#include "emoticontonecombobox.h"
+#include "emojicategorybuttons.h"
+#include "emojilistview.h"
+#include "emojitonecombobox.h"
 
 #include <KLocalizedString>
 #include <QLineEdit>
@@ -28,9 +28,9 @@ class EmoticonTextEditSelector::EmoticonTextEditSelectorPrivate
 public:
     explicit EmoticonTextEditSelectorPrivate(EmoticonTextEditSelector *q)
         : searchUnicodeLineEdit(new QLineEdit(q))
-        , categoryButtons(new EmoticonCategoryButtons(q))
-        , emoticonListView(new EmoticonListView(q))
-        , emoticonToneComboBox(new EmoticonToneComboBox(q))
+        , categoryButtons(new EmojiCategoryButtons(q))
+        , emoticonListView(new EmojiListView(q))
+        , emoticonToneComboBox(new EmojiToneComboBox(q))
         , emojiSortFilterProxyModel(new TextEmoticonsCore::EmojiSortFilterProxyModel(q))
         , qq(q)
     {
@@ -62,9 +62,9 @@ public:
     }
 
     QLineEdit *const searchUnicodeLineEdit;
-    EmoticonCategoryButtons *const categoryButtons;
-    EmoticonListView *const emoticonListView;
-    EmoticonToneComboBox *const emoticonToneComboBox;
+    EmojiCategoryButtons *const categoryButtons;
+    EmojiListView *const emoticonListView;
+    EmojiToneComboBox *const emoticonToneComboBox;
     TextEmoticonsCore::EmojiSortFilterProxyModel *const emojiSortFilterProxyModel;
     bool customEmojiSupport = false;
     EmoticonTextEditSelector *const qq;
@@ -74,7 +74,7 @@ EmoticonTextEditSelector::EmoticonTextEditSelector(QWidget *parent)
     : QWidget(parent)
     , d(new EmoticonTextEditSelectorPrivate(this))
 {
-    const int defaultFontSize{22};
+    constexpr int defaultFontSize{22};
     QFont f;
     f.setPointSize(defaultFontSize);
     f.setFamily(TextEmoticonsCore::EmoticonUnicodeUtils::emojiFontName());
@@ -104,11 +104,11 @@ EmoticonTextEditSelector::EmoticonTextEditSelector(QWidget *parent)
 
     d->emojiSortFilterProxyModel->setObjectName(u"mEmoticonProxyModel"_s);
     d->emoticonListView->setModel(d->emojiSortFilterProxyModel);
-    connect(d->emoticonListView, &EmoticonListView::fontSizeChanged, d->emoticonListView, &EmoticonListView::setFontSize);
-    connect(d->emoticonListView, &EmoticonListView::emojiItemSelected, this, [this](const QString &str, const QString &identifier) {
+    connect(d->emoticonListView, &EmojiListView::fontSizeChanged, d->emoticonListView, &EmojiListView::setFontSize);
+    connect(d->emoticonListView, &EmojiListView::emojiItemSelected, this, [this](const QString &str, const QString &identifier) {
         d->slotItemSelected(str, identifier);
     });
-    connect(d->categoryButtons, &EmoticonCategoryButtons::categorySelected, this, [this](const QString &category) {
+    connect(d->categoryButtons, &EmojiCategoryButtons::categorySelected, this, [this](const QString &category) {
         d->slotCategorySelected(category);
     });
     connect(d->searchUnicodeLineEdit, &QLineEdit::textChanged, this, [this](const QString &str) {
@@ -118,11 +118,11 @@ EmoticonTextEditSelector::EmoticonTextEditSelector(QWidget *parent)
         d->slotUsedIdentifierChanged(lst);
     });
 
-    connect(d->emoticonListView, &EmoticonListView::clearHistory, this, []() {
+    connect(d->emoticonListView, &EmojiListView::clearHistory, this, []() {
         TextEmoticonsCore::EmojiModelManager::self()->setRecentIdentifier(QStringList());
     });
 
-    connect(d->emoticonToneComboBox, &TextEmoticonsWidgets::EmoticonToneComboBox::currentIndexChanged, this, [this]() {
+    connect(d->emoticonToneComboBox, &TextEmoticonsWidgets::EmojiToneComboBox::currentIndexChanged, this, [this]() {
         TextEmoticonsCore::EmojiModelManager::self()->setEmojiTone(d->emoticonToneComboBox->currentEmojiTone());
     });
 
