@@ -28,7 +28,7 @@ void GrammarResultUtil::applyGrammarResult(const QVector<TextGrammarCheck::Gramm
                 for (int i = 0; i < blockNumberId; ++i) {
                     const QTextBlock block = document->findBlockByNumber(i);
                     if (block.isValid()) {
-                        if (block.text() != QLatin1Char('\n')) {
+                        if (block.text() != u'\n') {
                             startSelectionIndex -= block.length();
                         }
                     }
@@ -46,7 +46,7 @@ void GrammarResultUtil::applyGrammarResult(const QVector<TextGrammarCheck::Gramm
             QString toolTip = info.error();
             // TODO generate new tooltip!
             if (!info.url().isEmpty()) {
-                toolTip += QLatin1Char('\n') + i18n("See on: %1", info.url());
+                toolTip += u'\n' + i18n("See on: %1", info.url());
             }
             format.setToolTip(toolTip);
             TextGrammarCheck::GrammarAction act;
@@ -90,21 +90,22 @@ void GrammarResultUtil::replaceWord(const TextGrammarCheck::GrammarAction &act,
                 qCDebug(TEXTGRAMMARCHECK_LOG) << " Position  " << i;
                 QTextCharFormat currentCharFormat = cur.charFormat();
                 if (currentCharFormat.hasProperty(GrammarResultUtil::TextInfo::ReplaceFormatInfo)) {
-                    auto act = cur.charFormat().property(GrammarResultUtil::TextInfo::ReplaceFormatInfo).value<TextGrammarCheck::GrammarAction>();
-                    qCDebug(TEXTGRAMMARCHECK_LOG) << "BEFORE Update GrammarResultUtil::TextInfo::ReplaceFormatInfo " << act;
-                    act.setStart(act.start() + diff);
-                    qCDebug(TEXTGRAMMARCHECK_LOG) << "AFTER Update GrammarResultUtil::TextInfo::ReplaceFormatInfo " << act.start();
-                    currentCharFormat.setProperty(GrammarResultUtil::TextInfo::ReplaceFormatInfo, QVariant::fromValue(act));
+                    auto grammarAct = cur.charFormat().property(GrammarResultUtil::TextInfo::ReplaceFormatInfo).value<TextGrammarCheck::GrammarAction>();
+                    qCDebug(TEXTGRAMMARCHECK_LOG) << "BEFORE Update GrammarResultUtil::TextInfo::ReplaceFormatInfo " << grammarAct;
+                    grammarAct.setStart(grammarAct.start() + diff);
+                    qCDebug(TEXTGRAMMARCHECK_LOG) << "AFTER Update GrammarResultUtil::TextInfo::ReplaceFormatInfo " << grammarAct.start();
+                    currentCharFormat.setProperty(GrammarResultUtil::TextInfo::ReplaceFormatInfo, QVariant::fromValue(grammarAct));
 
                     const int newPosition = i - 1;
                     qCDebug(TEXTGRAMMARCHECK_LOG) << " newPosition " << newPosition;
                     qCDebug(TEXTGRAMMARCHECK_LOG) << "BEFORE Update GrammarResultUtil::TextInfo::ReplaceFormatInfo newPosition " << newPosition;
                     cur.setPosition(newPosition);
-                    cur.setPosition(newPosition + act.length(), QTextCursor::KeepAnchor);
-                    qCDebug(TEXTGRAMMARCHECK_LOG) << "AFTER Update GrammarResultUtil::TextInfo::ReplaceFormatInfo newPosition " << newPosition + act.length();
+                    cur.setPosition(newPosition + grammarAct.length(), QTextCursor::KeepAnchor);
+                    qCDebug(TEXTGRAMMARCHECK_LOG) << "AFTER Update GrammarResultUtil::TextInfo::ReplaceFormatInfo newPosition "
+                                                  << newPosition + grammarAct.length();
                     cur.setCharFormat(currentCharFormat);
 
-                    i += act.length();
+                    i += grammarAct.length();
                 }
             }
         }
