@@ -5,6 +5,8 @@
 */
 
 #include "grammalecteresultwidgettest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "common/grammarresulttextedit.h"
 #include "grammalecte/grammalecteresultwidget.h"
 #include <QTest>
@@ -20,14 +22,14 @@ GrammarResultWidgetTest::GrammarResultWidgetTest(QObject *parent)
 void GrammarResultWidgetTest::shouldHaveDefaultValue()
 {
     TextGrammarCheck::GrammalecteResultWidget w;
-    auto mainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainlayout"));
+    auto mainLayout = w.findChild<QVBoxLayout *>(u"mainlayout"_s);
     QVERIFY(mainLayout);
     QCOMPARE(mainLayout->contentsMargins(), QMargins());
 
-    auto mResult = w.findChild<TextGrammarCheck::GrammarResultTextEdit *>(QStringLiteral("grammarResult"));
+    auto mResult = w.findChild<TextGrammarCheck::GrammarResultTextEdit *>(u"grammarResult"_s);
     QVERIFY(mResult);
 
-    auto closeBtn = w.findChild<QToolButton *>(QStringLiteral("close-button"));
+    auto closeBtn = w.findChild<QToolButton *>(u"close-button"_s);
     QVERIFY(closeBtn);
     // QVERIFY(!closeBtn->icon().isNull());
     QVERIFY(!closeBtn->toolTip().isEmpty());
