@@ -4,6 +4,8 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "grammalecteurlrequesterwidgettest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "grammalecte/grammalecteurlrequesterwidget.h"
 #include <QHBoxLayout>
 #include <QLineEdit>
@@ -21,15 +23,15 @@ void GrammalecteUrlRequesterWidgetTest::shouldHaveDefaultValues()
 {
     TextGrammarCheck::GrammalecteUrlRequesterWidget w;
 
-    auto mainLayout = w.findChild<QHBoxLayout *>(QStringLiteral("mainLayout"));
+    auto mainLayout = w.findChild<QHBoxLayout *>(u"mainLayout"_s);
     QVERIFY(mainLayout);
     QCOMPARE(mainLayout->contentsMargins(), QMargins{});
 
-    auto mLineEdit = w.findChild<QLineEdit *>(QStringLiteral("mLineEdit"));
+    auto mLineEdit = w.findChild<QLineEdit *>(u"mLineEdit"_s);
     QVERIFY(mLineEdit);
     QVERIFY(mLineEdit->text().isEmpty());
 
-    auto selectUrlButton = w.findChild<QToolButton *>(QStringLiteral("selectUrlButton"));
+    auto selectUrlButton = w.findChild<QToolButton *>(u"selectUrlButton"_s);
     QVERIFY(selectUrlButton);
     QVERIFY(!selectUrlButton->text().isEmpty());
 }
