@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -17,6 +17,6 @@ class TEXTGRAMMARCHECK_TESTS_EXPORT GrammalecteParser
 public:
     GrammalecteParser();
     ~GrammalecteParser();
-    Q_REQUIRED_RESULT QVector<GrammarError> parseResult(const QJsonObject &obj) const;
+    [[nodiscard]] QVector<GrammarError> parseResult(const QJsonObject &obj) const;
 };
 }
