@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2022-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2022-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -19,7 +19,7 @@ public:
     ~GrammalecteUrlRequesterWidget() override;
 
     void setPath(const QString &path);
-    Q_REQUIRED_RESULT QString path() const;
+    [[nodiscard]] QString path() const;
 
     void setPlaceholderText(const QString &text);
 
