@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -19,12 +19,12 @@ public:
     ~LanguageToolComboBox() override;
 
     void setLanguage(const QString &str);
-    Q_REQUIRED_RESULT QString language() const;
+    [[nodiscard]] QString language() const;
 
     void fillComboBox(const QVector<LanguageInfo> &info);
 
 private:
-    void fillComboBox();
+    TEXTGRAMMARCHECK_NO_EXPORT void fillComboBox();
     Q_DISABLE_COPY(LanguageToolComboBox)
 };
 }
