@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -20,7 +20,7 @@ public:
     void setTesting(bool b);
 
 private:
-    Q_REQUIRED_RESULT static QStringList parseSuggestion(const QJsonObject &obj);
+    [[nodiscard]] static QStringList parseSuggestion(const QJsonObject &obj);
     bool mTesting = false;
 };
 }
