@@ -1,15 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "languagetoolparser.h"
+
 #include "languagetoolgrammarerror.h"
 
 #include <QJsonArray>
 
 using namespace TextGrammarCheck;
+using namespace Qt::Literals::StringLiterals;
 
 LanguageToolParser::LanguageToolParser() = default;
 
@@ -18,7 +20,7 @@ LanguageToolParser::~LanguageToolParser() = default;
 QVector<GrammarError> LanguageToolParser::parseResult(const QJsonObject &obj) const
 {
     QVector<GrammarError> infos;
-    const QJsonArray array = obj.value(QLatin1String("matches")).toArray();
+    const QJsonArray array = obj.value("matches"_L1).toArray();
     for (const QJsonValue &current : array) {
         // qDebug() << " current " << current;
         if (current.type() == QJsonValue::Object) {
