@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -16,6 +16,6 @@ class TEXTGRAMMARCHECK_TESTS_EXPORT LanguageToolParser
 public:
     LanguageToolParser();
     ~LanguageToolParser();
-    Q_REQUIRED_RESULT QVector<TextGrammarCheck::GrammarError> parseResult(const QJsonObject &obj) const;
+    [[nodiscard]] QVector<TextGrammarCheck::GrammarError> parseResult(const QJsonObject &obj) const;
 };
 }
