@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -72,7 +72,9 @@ void LanguageToolUpdateComboBox::setLanguageToolCombobox(LanguageToolComboBox *l
 void LanguageToolUpdateComboBox::slotGetLanguagesError(const QString &error)
 {
     qCWarning(TEXTGRAMMARCHECK_LOG) << "Error during loading languages from server : " << error;
-    KMessageBox::error(parentWidget(), i18n("An error occurred attempting to load the list of available languages:\n%1", error), i18n("List of Languages"));
+    KMessageBox::error(parentWidget(),
+                       i18n("An error occurred attempting to load the list of available languages:\n%1", error),
+                       i18nc("@title:window", "List of Languages"));
 }
 
 void LanguageToolUpdateComboBox::slotGetLanguagesFinished(const QString &result)
