@@ -20,9 +20,8 @@ bool SpeechToTextClient::hasConfigurationDialog() const
     return false;
 }
 
-bool SpeechToTextClient::showConfigureDialog(QWidget *parentWidget)
+bool SpeechToTextClient::showConfigureDialog([[maybe_unused]] QWidget *parentWidget)
 {
-    Q_UNUSED(parentWidget);
     // Nothing by default
     return false;
 }
