@@ -4,6 +4,8 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "speechtotextconfigurewidgettest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "speechtotext/widgets/speechtotextcomboboxwidget.h"
 #include "speechtotext/widgets/speechtotextconfigurewidget.h"
 #include "speechtotext/widgets/speechtotextselectdevicewidget.h"
@@ -21,14 +23,14 @@ void SpeechToTextConfigureWidgetTest::shouldHaveDefaultValues()
 {
     TextSpeechToText::SpeechToTextConfigureWidget w;
 
-    auto mainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainLayout"));
+    auto mainLayout = w.findChild<QVBoxLayout *>(u"mainLayout"_s);
     QVERIFY(mainLayout);
     QCOMPARE(mainLayout->contentsMargins(), QMargins{});
 
-    auto mSpeechToTextComboBox = w.findChild<TextSpeechToText::SpeechToTextComboBoxWidget *>(QStringLiteral("mSpeechToTextComboBox"));
+    auto mSpeechToTextComboBox = w.findChild<TextSpeechToText::SpeechToTextComboBoxWidget *>(u"mSpeechToTextComboBox"_s);
     QVERIFY(mSpeechToTextComboBox);
 
-    auto mSpeechToTextDevice = w.findChild<TextSpeechToText::SpeechToTextSelectDeviceWidget *>(QStringLiteral("mSpeechToTextDevice"));
+    auto mSpeechToTextDevice = w.findChild<TextSpeechToText::SpeechToTextSelectDeviceWidget *>(u"mSpeechToTextDevice"_s);
     QVERIFY(mSpeechToTextDevice);
 }
 
