@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,9 +7,6 @@
 #pragma once
 
 #include <QObject>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-class QNetworkConfigurationManager;
-#endif
 namespace TextTranslator
 {
 /**
@@ -24,14 +21,9 @@ public:
     ~NetworkManager() override;
     static NetworkManager *self();
 
-    Q_REQUIRED_RESULT bool isOnline() const;
+    [[nodiscard]] bool isOnline() const;
 
 Q_SIGNALS:
     void networkStatusChanged(bool isOnline);
-
-private:
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QNetworkConfigurationManager *const mNetworkConfigureManager;
-#endif
 };
 }
