@@ -5,6 +5,8 @@
 */
 
 #include "managermodeltranslatortest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "managermodeltranslator.h"
 #include <QTest>
 QTEST_MAIN(ManagerModelTranslatorTest)
@@ -24,17 +26,17 @@ void ManagerModelTranslatorTest::shouldParseJson_data()
 {
     QTest::addColumn<QString>("fileName");
     QTest::addColumn<int>("numberOfTranslator");
-    QTest::newRow("empty") << QStringLiteral("empty") << 0;
-    QTest::newRow("fullmodels") << QStringLiteral("models") << 21;
+    QTest::newRow("empty") << u"empty"_s << 0;
+    QTest::newRow("fullmodels") << u"models"_s << 21;
     // 1 correct 1 invalid
-    QTest::newRow("invalid") << QStringLiteral("invalid") << 1;
+    QTest::newRow("invalid") << u"invalid"_s << 1;
 }
 
 void ManagerModelTranslatorTest::shouldParseJson()
 {
     QFETCH(QString, fileName);
     QFETCH(int, numberOfTranslator);
-    const QString originalJsonFile = QLatin1String(BERGAMOT_DATA_DIR) + QStringLiteral("/modellanguages/") + fileName + QStringLiteral(".json");
+    const QString originalJsonFile = QLatin1String(BERGAMOT_DATA_DIR) + u"/modellanguages/"_s + fileName + u".json"_s;
     ManagerModelTranslator w;
     w.loadModelList(originalJsonFile);
     QCOMPARE(w.translators().count(), numberOfTranslator);
