@@ -1,21 +1,20 @@
 /*
-  SPDX-FileCopyrightText: 2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2023-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 #pragma once
 #include "libbergamot_export.h"
-#include <QDir>
 #include <QString>
 
 namespace BergamotEngineUtils
 {
-Q_REQUIRED_RESULT LIBBERGAMOT_EXPORT QString defaultBergamotRepository();
-Q_REQUIRED_RESULT LIBBERGAMOT_EXPORT QString groupName();
-Q_REQUIRED_RESULT LIBBERGAMOT_EXPORT QString coreNumberKey();
-Q_REQUIRED_RESULT LIBBERGAMOT_EXPORT QString memoryByThreadKey();
-Q_REQUIRED_RESULT LIBBERGAMOT_EXPORT QString storageLanguagePath();
-Q_REQUIRED_RESULT LIBBERGAMOT_EXPORT QString useLocalCacheKey();
+[[nodiscard]] LIBBERGAMOT_EXPORT QString defaultBergamotRepository();
+[[nodiscard]] LIBBERGAMOT_EXPORT QString groupName();
+[[nodiscard]] LIBBERGAMOT_EXPORT QString coreNumberKey();
+[[nodiscard]] LIBBERGAMOT_EXPORT QString memoryByThreadKey();
+[[nodiscard]] LIBBERGAMOT_EXPORT QString storageLanguagePath();
+[[nodiscard]] LIBBERGAMOT_EXPORT QString useLocalCacheKey();
 
 struct LIBBERGAMOT_EXPORT LanguageInstalled {
     QString from;
@@ -23,10 +22,10 @@ struct LIBBERGAMOT_EXPORT LanguageInstalled {
     QString shortName;
     QString absoluteLanguageModelPath;
     int version = -1;
-    Q_REQUIRED_RESULT bool operator==(const LanguageInstalled &other) const;
+    [[nodiscard]] bool operator==(const LanguageInstalled &other) const;
 };
 
-Q_REQUIRED_RESULT LIBBERGAMOT_EXPORT QVector<LanguageInstalled> languageLocallyStored(const QString &path = {});
+[[nodiscard]] LIBBERGAMOT_EXPORT QVector<LanguageInstalled> languageLocallyStored(const QString &path = {});
 struct LIBBERGAMOT_EXPORT SettingsInfo {
     void loadSettingsInfo();
     void saveSettingsInfo();
