@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2023-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -19,7 +19,7 @@ public:
     ~BergamotEngineWidget() override;
 
     void setSettingsInfo(const BergamotEngineUtils::SettingsInfo &info);
-    Q_REQUIRED_RESULT BergamotEngineUtils::SettingsInfo settingsInfo() const;
+    [[nodiscard]] BergamotEngineUtils::SettingsInfo settingsInfo() const;
 
 private:
     QTabWidget *const mTabWidget;
