@@ -5,6 +5,8 @@
 */
 
 #include "deeplengineclienttest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "../deeplengineclient.h"
 #include <QTest>
 QTEST_MAIN(DeeplEngineClientTest)
@@ -17,7 +19,7 @@ DeeplEngineClientTest::DeeplEngineClientTest(QObject *parent)
 void DeeplEngineClientTest::shouldHaveDefaultValues()
 {
     DeeplEngineClient client;
-    QCOMPARE(client.name(), QStringLiteral("deepl"));
+    QCOMPARE(client.name(), u"deepl"_s);
     QVERIFY(client.createTranslator());
     QVERIFY(!client.translatedName().isEmpty());
     QVERIFY(!client.supportedFromLanguages().isEmpty());
