@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2022-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2022-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -16,9 +16,9 @@ public:
     explicit DeeplEngineConfigureWidget(QWidget *parent = nullptr);
     ~DeeplEngineConfigureWidget() override;
     void setUseFreeLicenceKey(bool b);
-    Q_REQUIRED_RESULT bool useFreeLicenceKey() const;
+    [[nodiscard]] bool useFreeLicenceKey() const;
 
-    Q_REQUIRED_RESULT QString apiKey() const;
+    [[nodiscard]] QString apiKey() const;
     void setApiKey(const QString &key);
 
 private:
