@@ -48,14 +48,14 @@ void DeeplEnginePlugin::translateText()
 
     QUrl url(mServerUrl);
     QUrlQuery query;
-    query.addQueryItem(QStringLiteral("text"), inputText());
-    query.addQueryItem(QStringLiteral("source_lang"), languageCode(from()));
-    query.addQueryItem(QStringLiteral("target_lang"), languageCode(to()));
+    query.addQueryItem(u"text"_s, inputText());
+    query.addQueryItem(u"source_lang"_s, languageCode(from()));
+    query.addQueryItem(u"target_lang"_s, languageCode(to()));
     url.setQuery(query);
 
     QNetworkRequest request(url);
     request.setRawHeader(QByteArrayLiteral("Authorization"), "DeepL-Auth-Key " + mApiKey.toLocal8Bit());
-    request.setHeader(QNetworkRequest::ContentTypeHeader, QStringLiteral("application/x-www-form-urlencoded"));
+    request.setHeader(QNetworkRequest::ContentTypeHeader, u"application/x-www-form-urlencoded"_s);
 
     QNetworkReply *reply = TextTranslator::TranslatorEngineAccessManager::self()->networkManager()->post(request, QByteArray());
     connect(reply, &QNetworkReply::errorOccurred, this, [this, reply](QNetworkReply::NetworkError error) {
@@ -83,11 +83,11 @@ void DeeplEnginePlugin::parseTranslation(QNetworkReply *reply)
     const QJsonObject responseObject = jsonResponse.object();
     // QJsonObject({"translations":[{"detected_source_language":"EN","text":"Bonjour le monde"}]})
     qCDebug(TRANSLATOR_DEEPL_LOG) << " responseObject " << responseObject;
-    const QJsonArray arrayTranslation = responseObject.value(QStringLiteral("translations")).toArray();
+    const QJsonArray arrayTranslation = responseObject.value(u"translations"_s).toArray();
     qCDebug(TRANSLATOR_DEEPL_LOG) << " arrayTranslation " << arrayTranslation;
     const QJsonObject obj = arrayTranslation.at(0).toObject();
 
-    setResult(obj.value(QStringLiteral("text")).toString());
+    setResult(obj.value(u"text"_s).toString());
     reply->deleteLater();
     qCDebug(TRANSLATOR_DEEPL_LOG) << " result " << result();
     Q_EMIT translateDone();
@@ -97,7 +97,7 @@ void DeeplEnginePlugin::loadSettings()
 {
     KConfigGroup myGroup(KSharedConfig::openConfig(), DeeplEngineUtil::groupName());
     mUseFreeLicense = myGroup.readEntry(DeeplEngineUtil::freeLicenseKey(), false);
-    mServerUrl = mUseFreeLicense ? QStringLiteral("https://api-free.deepl.com/v2/translate") : QStringLiteral("https://api.deepl.com/v2/translate");
+    mServerUrl = mUseFreeLicense ? u"https://api-free.deepl.com/v2/translate"_s : u"https://api.deepl.com/v2/translate"_s;
     auto readJob = new QKeychain::ReadPasswordJob(DeeplEngineUtil::translatorGroupName(), this);
     connect(readJob, &QKeychain::Job::finished, this, &DeeplEnginePlugin::slotApiKeyRead);
     readJob->setKey(DeeplEngineUtil::apiGroupName());
@@ -123,9 +123,9 @@ void DeeplEnginePlugin::slotConfigureChanged()
 QString DeeplEnginePlugin::languageCode(const QString &langStr)
 {
     if (langStr == "auto"_L1) {
-        return QStringLiteral("auto-detect");
+        return u"auto-detect"_s;
     } else if (langStr == "zh-CN"_L1) {
-        return QStringLiteral("zh");
+        return u"zh"_s;
     }
     return langStr;
 }
