@@ -5,6 +5,8 @@
 */
 
 #include "lingvaenginedialog.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "lingvaenginewidget.h"
 
 #include <KLocalizedString>
@@ -16,14 +18,14 @@ LingvaEngineDialog::LingvaEngineDialog(QWidget *parent)
     , mConfigureWidget(new LingvaEngineWidget(this))
 {
     setWindowTitle(i18nc("@title:window", "Configure Engine"));
-    mConfigureWidget->setObjectName(QStringLiteral("mConfigureWidget"));
+    mConfigureWidget->setObjectName(u"mConfigureWidget"_s);
 
     auto mainLayout = new QVBoxLayout(this);
-    mainLayout->setObjectName(QStringLiteral("mainLayout"));
+    mainLayout->setObjectName(u"mainLayout"_s);
     mainLayout->addWidget(mConfigureWidget);
 
     auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
-    buttonBox->setObjectName(QStringLiteral("buttonBox"));
+    buttonBox->setObjectName(u"buttonBox"_s);
     mainLayout->addWidget(buttonBox);
     connect(buttonBox, &QDialogButtonBox::accepted, this, &LingvaEngineDialog::accept);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &LingvaEngineDialog::reject);
