@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2022-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2022-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -19,7 +19,7 @@ public:
 
     void slotConfigureChanged();
 
-    Q_REQUIRED_RESULT QString languageCode(const QString &langStr) override;
+    [[nodiscard]] QString languageCode(const QString &langStr) override;
 
 private:
     void loadSettings();
