@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -25,7 +25,7 @@ private:
     void slotSaveAs();
     void readConfig();
     void saveTextAs(const QString &text, const QString &filter, QWidget *parent, const QUrl &url = {}, const QString &caption = {});
-    Q_REQUIRED_RESULT bool saveToFile(const QString &filename, const QString &text);
+    [[nodiscard]] bool saveToFile(const QString &filename, const QString &text);
     void writeConfig();
     QPlainTextEdit *const mEdit;
     QPushButton *const mUser1Button;
